/*########################################################################*/
/*#                                                                      #*/
/*#                                                                      #*/
/*#           Copyright (c) 2002 IskraTEL                                #*/
/*#                                                                      #*/
/*#                                                                      #*/
/*# Name        : c_errcode.h                                            #*/
/*#                                                                      #*/
/*# Description : definitions of system error codes                      #*/
/*#                                                                      #*/
/*# Date        : Sep, 2002                                              #*/
/*#                                                                      #*/
/*# Author      : Marko Stetner, RDSS3                                   #*/
/*#                                                                      #*/
/*# Remarks     :                                                     	 #*/
/*#                                                                      #*/
/*# Revisions   : Sep. 1998, Bostjan Mulej, RDSS 3                       #*/
/*#               Added ERR_RN1_ALLOC to detect full region #1           #*/
/*#               June 1999, Tone Gorjanc, new codes for PRA driver      #*/
/*#               on MPC860MH                                            #*/
/*#                                                                      #*/
/*#             * Feb. 2000, Tomo Bogataj, RDSP5                         #*/
/*#               Added codes for filesystem transaction control.        #*/
/*#                                                                      #*/
/*#             * Sep. 2002, K&O Mikrosistemi Kranj d.o.o., Adam Klancar #*/
/*#               Added codes for CLI.                                   #*/
/*#                                                                      #*/
/*########################################################################*/

#if !defined(DIAGNOSTIC_V6) && !defined(diagnostics)
#include "rte_conf.h"
#endif /* !defined(DIAGNOSTIC_V6) && !defined(diagnostics) */

# ifndef _C_ERRCODE_H
# define _C_ERRCODE_H

/****************************************************************/
/*          EXTERNAL FUNCTIONS                                 	*/
/****************************************************************/

#if defined(SYSERR_TO_MSG) || defined(PLATFORM_SGK)

#  define syserr(err_code, par)	Msg(err_code, par, 0)
#ifdef __cplusplus
extern "C" {
#endif
   extern	int	Msg(unsigned long , unsigned long, char *, ... );
#ifdef __cplusplus
};
#endif
   extern       char    *GetFileName(char *file_name);

#else	/********************** NOT o551b, o561 , o551c*****************/

   extern  void    syserr(int , int );

#endif	/********************** *** o551b, o561 , o551c*****************/

/****************************************************************/
/*          CONSTANTS                                           */
/****************************************************************/

/************************************************************************/
/* data type definition: message					*/
/************************************************************************/
struct s_msg {
    char	*symb;			/* message symbol		*/
    char	*desc;			/* message description		*/
    int		code;			/* message code			*/
    char	psos;			/* pSOS function error		*/
};
typedef struct s_msg t_msg;

#define MASK_CODE_ITEM(code, item) \
		(code & (((1 << NBIT_ ## item) - 1) << BPOS_ ## item))

#define GET_CODE_ITEM(code, item) \
		(code >> BPOS_ ## item) & ((1 << NBIT_ ## item) - 1)

#define REQ_ALL	 0	/* request complete message code description	*/
#define REQ_SYMB 1	/* request only symbol of msg code description	*/
#define REQ_DESC 2	/* request description without symbol string	*/

# define CDA_BLOCK_STRING "CDA_BLOCK"
# define  L_SYSERRINT   0x10	/* noumber of celld reserved for syserr from interrupt */

/****************************************************************/
/*          MESSAGE CODES                                         */
/****************************************************************/
/************************************************************************/
/*   Message code structure						*/
/************************************************************************/
/*   3             2 2             1 1					*/
/*   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 	*/
/*  +-------+-+-----+-------+-------+-------+-------+-------+-------+	*/
/*  | |S|dst|B| lvl |flt|fmt|   SW module   |      description      |	*/
/*  +-------+-+-----+-------+-------+-------+-------+-------+-------+	*/
/*									*/
/*  Notes:								*/
/*	1. S - system /application message				*/
/*      2. B - binary / ASCII data type					*/
/*	3. Number of bits for particular bit field may vary from	*/
/*	   given picture. Exact numbers are defined bellow.		*/
/*									*/
/************************************************************************/

#define	NBIT_MSG_DES	12	/* nr of bits for error description	*/
#define NBIT_MODUL	8	/* nr of bits for SW modul code		*/
#define NBIT_MSG_FMT	2	/* nr of bits for message format	*/
#define	NBIT_MSG_FILT	2	/* nr of bits for message filtering	*/
#define	NBIT_MSG_LVL	3	/* nr of bits for message type		*/
#define	NBIT_MSG_BIN	1	/* nr of bits for bin/text type		*/
#define	NBIT_MSG_DST	2	/* nr of bits for destination		*/
#define NBIT_APL_SYS	1	/* nr of bits for applic./system flag	*/

#define BPOS_MSG_DES	0	/* msg descritpion bit position		*/
#define	BPOS_MODUL	(BPOS_MSG_DES + NBIT_MSG_DES)	/* 12		*/
#define	BPOS_MSG_FMT	(BPOS_MODUL + NBIT_MODUL)	/* 20		*/
#define	BPOS_MSG_FILT	(BPOS_MSG_FMT + NBIT_MSG_FMT)	/* 22		*/
#define	BPOS_MSG_LVL	(BPOS_MSG_FILT + NBIT_MSG_FILT) /* 24		*/
#define	BPOS_MSG_BIN	(BPOS_MSG_LVL + NBIT_MSG_LVL)   /* 27		*/
#define	BPOS_MSG_DST	(BPOS_MSG_BIN + NBIT_MSG_BIN)	/* 28		*/
#define	BPOS_APL_SYS	(BPOS_MSG_DST + NBIT_MSG_DST)	/* 30		*/


/************************************************************************/
/*	MESSAGE LEVEL codes definitions					*/
/************************************************************************/
#define	X_ERR		(0x0 << BPOS_MSG_LVL)		/* 0x1000	*/
#define	X_WRN		(0x1 << BPOS_MSG_LVL)		/* 0x2000	*/
#define	X_INI		(0x2 << BPOS_MSG_LVL)		/* 0x3000	*/
#define	X_APP		(0x3 << BPOS_MSG_LVL)		/* 0x4000	*/
#define	X_INF		(0x4 << BPOS_MSG_LVL)		/* 0x5000	*/
#define	X_FAT		(0x5 << BPOS_MSG_LVL)		/* measure is reset ! */

/************************************************************************/
/*	BINARY MESSAGE number bit position				*/
/************************************************************************/
#define MSG_FMT_BIN	(1 << BPOS_MSG_BIN)

/************************************************************************/
/*	MESSAGE FORMAT number bit position				*/
/************************************************************************/
#define	MSG_FMT_STAT	(1 << BPOS_MSG_FMT)
#define	MSG_FMT_LOG	(2 << BPOS_MSG_FMT)

/************************************************************************/
/*	DESTINATION codes definitions					*/
/************************************************************************/
#define	X_NONE		(3 << BPOS_MSG_DST)		/* no output	*/
#define	X_CON		(2 << BPOS_MSG_DST)		/* console	*/
#define	X_FILE		(1 << BPOS_MSG_DST)		/* file		*/
#define	X_BOTH		(0 << BPOS_MSG_DST)		/* both		*/

/************************************************************************/
/*	Application / system errors distinguishing bit mask		*/
/************************************************************************/
#define	X_APL		(0 << BPOS_APL_SYS)		/* 0x000	*/
#ifdef DG_MSG_DESC
#define	X_SYS		(1 << BPOS_APL_SYS)		/* 0x800	*/
#else
#define	X_SYS		(0 << BPOS_APL_SYS)		/* 0x800	*/
#endif /* DG_MSG_DESC */

/************************************************************************/
/*	MESSAGE FILTERING DISABLE bit position				*/
/************************************************************************/
#define	MSG_NOFILT	(1 << BPOS_MSG_FILT)

#define MASK_MSG_DES	(((1 << NBIT_MSG_DES) - 1) << BPOS_MSG_DES)
#define MASK_MSG_DST	(((1 << NBIT_MSG_DST) - 1) << BPOS_MSG_DST)
#define MASK_MODUL	(((1 << NBIT_MODUL) - 1) << BPOS_MODUL)
#define MASK_MSG_FMT	(((1 << NBIT_MSG_FMT) - 1) << BPOS_MSG_FMT)
#define MASK_MSG_NOFILT	(((1 << NBIT_MSG_FILT) - 1) << BPOS_MSG_FILT)
#define MASK_MSG_LVL	(((1 << NBIT_MSG_LVL) - 1) << BPOS_MSG_LVL)
#define MASK_MSG_BIN	(((1 << NBIT_MSG_BIN) - 1) << BPOS_MSG_BIN)


/****************************************************************/
/*          ERROR CODES                                         */
/****************************************************************/
/*************************************/
/*          Offsets for modules      */
/*************************************/
# define	L1_OFFSET		0x1000  /* S interface */
# define	DSP_OFFSET		0x2000
# define	SDL_OFFSET		0x3000
# define	TRC_OFFSET		0x4000
# define	DIAG_OFFSET		0x5000
# define	SR_OFFSET		0x6000
# define	RTDB_OFFSET		0x7000
# define    	MMU_OFFSET      	0x8000
# define    	MEM_OFFSET      	0x9000
# define	L1U_OFFSET		0xa000  /* U interface */
# define	CAS_OFFSET		0xb000
# define	PER_OFFSET		0xc000  /* analog per  */
# define	TAB_OFFSET		0xd000  /* trunk and anal. perif  */
# define	BIO_OFFSET		0xe000  /* BIO/T1/CAS */
# define	SO_OFFSET		0xf000  /* Switch Over */
# define	PKTP_OFFSET		0x10000 /* Packet Communication */
# define	MTP_OFFSET		0x11000 /* MTP (SSN7) */
# define	IL_OFFSET		0x12000	/* IL */
# define        SHM_OFFSET              0x13000 /* SHM */
# define	PRA860_OFFSET		0x14000  /* PRA860/T1/CAS860 */
# define	CAS860_OFFSET		0x15000  /* PRA860/T1/CAS860 */
# define	VOIP860_OFFSET		0x16000  /* VOIP 860 */
# define	CPROT_OFFSET		0x17000  /* System protection */
# define	ALRP_OFFSET		0x18000  /* Alarm Panel		*/
# define	DTRC_OFFSET		0x19000 /* Diagnostic tracer messages */
# define	XCTRL_OFFSET		0x1A000	/* Filesystem transaction control */
# define	STRC_OFFSET		0x1B000  /* signal tracer	*/
# define	SAC_OFFSET		0x1C000  /* SAC			*/
# define	SIRAM_OFFSET		0x1D000  /* SIRAM		*/
# define	PIPC_OFFSET		0x1E000  /* PIPC - Packet InterProcesor Comunication */
# define	AAL_OFFSET		0x1F000  /* AAL - ATM Adaptation Layer (ATIC stack) */
# define        ATM_OFFSET              0x20000  /* ATM panel */
# define        BSTST_OFFSET            0x21000  /* broadband statistic */
# define        INITMNG_OFFSET          0x22000  /* Init manager */
# define        VOIP_OFFSET             0x23000  /* VOIP */
# define        CLI_OFFSET              0x24000  /* Command Line Interface */
# define        SW_OFFSET               0x25000  /* Digital switch offset */
# define        AT_OFFSET               0x26000  
# define        WV_OFFSET               0x27000  /* Windview offset */
# define        MDIM_OFFSET             0x28000  /* Dsp Interface Module offset */
# define	H323_OFFSET		0x29000  /* H323 Module offset */
# define	PPP_OFFSET		0x2A000  /* PPP Module offset */
# define        ETH_OFFSET              0x2B000  /* Ethernet module offset */
# define	NTP_OFFSET		0x2C000  /* NTP module offset */
# define	BRIDGE_OFFSET		0x2D000  /* Bridge module offset */
# define	DRH_OFFSET		0x2E000  /* DRH - Diagnostic Report Handler	*/
# define	RTCP_OFFSET		0x2F000  /* RTCP module offset */
# define	ACS_OFFSET		0x30000  /* ACS - Autoconfiguration server	*/
# define	LVL7_OFFSET		0x31000  /* LVL7 module offset */
# define	VINETIC_OFFSET		0x32000  /* VINETIC - driver */
# define	AALN_OFFSET		0x33000  /* VINETIC - API interface */
# define	MGCP_OFFSET		0x34000  /* Application MGCP */
# define	ETHSW_OFFSET		0x35000  /* BCM ethernet switch */
# define	SSH_OFFSET	 	0x36000  /* SSH module offset */
# define	MEG_OFFSET		0x37000  /* Application Megaco*/
# define        CPM_OFFSET		0x38000  /*PQII/PQIII CPM */
# define        IPMC_OFFSET             0x39000  /* IPMC firmware update offset */
# define	DHCPC_OFFSET	        0x3A000  /* DHCP Client */
# define	MLNC_OFFSET             0x3B000  /* Multi-Link Network Conectivity */
# define	DGM_OFFSET		0x3C000  /* DGM - Diagnostic Monitor */
# define	FLASH_BBM_OFFSET	0x3D000  /* BBM - Flash bad block management */
# define	DSS1_OFFSET		0x3E000  /* DSS1 signalisation */
# define	LIDIA_OFFSET		0x3F000  /* LIDIA - LInk DIAgnostic */
# define        ODBC_OFFSET             0x40000  /* ODBC - Open Data Base Connectivity */
# define	ZL_DIAG_OFFSET		0x41000  /* Zarlink device diagnostics */
# define	MACSG_OFFSET		0x42000  /* Mac Source Guard */
# define	V52_OFFSET		0x43000  /* V5.2 interface signalisation */
# define	SNMP_OFFSET		0x44000  /* SNMP agent */
# define	SYSCONF_OFFSET		0x45000  /* System Configuration */
# define	HW_INIT_OFFSET		0x46000  /* HW initialization */
# define	RCM_OFFSET		0x47000  /* Redundancy communication manager */
# define	ISS_OFFSET		0x48000  /* ISS messages - IDK platform	*/

/***************************************************/
/*          Error codes for L1 DSS1 (S interface)  */
/***************************************************/
# define ERR_L1_SPURIOUS_INT	L1_OFFSET+0x00+X_FAT	/* reset */
# define ERR_L1_BOARD_INT_ERROR	L1_OFFSET+0x01		/* board is out of service - interrupt disable */
# define ERR_L1_DRV_ERROR	L1_OFFSET+0x02		/* just for statistics */
# define ERR_L1_GET_QID		L1_OFFSET+0x03+X_FAT	/* reset */
# define ERR_L1_GET_TID		L1_OFFSET+0x04+X_FAT	/* reset */
# define ERR_L1_T_CREATE	L1_OFFSET+0x05+X_FAT	/* reset */
# define ERR_L1_Q_CREATE	L1_OFFSET+0x06+X_FAT	/* reset */
# define ERR_L1_SM_CREATE	L1_OFFSET+0x07+X_FAT	/* reset */
# define ERR_L1_EV_EVERY	L1_OFFSET+0x08+X_FAT	/* reset */
# define ERR_L1_EV_RECEIVE	L1_OFFSET+0x09+X_FAT	/* reset */
# define ERR_L1_T_START		L1_OFFSET+0x0a+X_FAT	/* reset */
# define ERR_L1_Q_SEND		L1_OFFSET+0x0b+X_FAT	/* reset */
# define ERR_L1_Q_RECEIVE	L1_OFFSET+0x0c		/* just for statistics */
# define ERR_L1_GETMEM		L1_OFFSET+0x0d+X_FAT	/* reset */
# define ERR_L1_FREEMEM		L1_OFFSET+0x0e +X_FAT	/* reset */
# define ERR_L1_ACCESS_NR_ERROR	L1_OFFSET+0x0f		/* just for statistics */
# define ERR_L1_INIT		L1_OFFSET+0x10+X_FAT	/* reset */
# define ERR_L1_LOST_SYNC	L1_OFFSET+0x11	/* just for statistics */
# define ERR_L1_RX_FRAME_CRC_ERROR	L1_OFFSET+0x12	/* just for statistics */
# define ERR_L1_RX_FRAME_RDO_ERROR	L1_OFFSET+0x13	/* just for statistics */
# define ERR_L1_RX_FRAME_RAB_ERROR	L1_OFFSET+0x14	/* just for statistics */
# define ERR_L1_TX_FRAME_ERROR	L1_OFFSET+0x15	/* just for statistics */
# define ERR_L1_TX_QUEUE_FULL	L1_OFFSET+0x16	/* just for statistics */
# define ERR_L1_CI_INT_LOST_SIG_LVL	L1_OFFSET+0x20	/* too many LSL interrupts per second */ /*4.4.2002 rkod*/
# define ERR_L1_CI_INT_LOST_FRAM	L1_OFFSET+0x21	/* too many RSYU interrupts per second */
# define ERR_L1_CI_INT_ACT_REQ		L1_OFFSET+0x22	/* too many ARU interrupts per second */
# define ERR_L1_CI_INT_ACT_IND		L1_OFFSET+0x23	/* too many AIU interrupts per second */
# define ERR_L1_CI_INT_DEACT_IND	L1_OFFSET+0x24	/* too many DIU interrupts per second */
# define ERR_L1_CI_INT_DEF			L1_OFFSET+0x25	/* too many OTHER interrupts per second */

/*************************************/
/*          Error codes for DSP      */
/*************************************/
# define ERR_DSP_SYS_ERR	DSP_OFFSET+0x00	/* reset */
# define ERR_DSP_TIME_OUT	DSP_OFFSET+0x01	/* reset */
# define ERR_DSP_LOAD_ERR 	DSP_OFFSET+0x02 /* instalation + reset */
# define ERR_DSP_ERR		DSP_OFFSET+0x03	/* reset */
# define ERR_DSP_X_MSG_L2	DSP_OFFSET+0x04	/* just for statistic */
# define ERR_DSP_X_MSG_DSP	DSP_OFFSET+0x05	/* just for statistic */
# define ERR_DSP_Q_REC_E	DSP_OFFSET+0x06	/* just for statistic */
# define ERR_DSP_Q_SND_E	DSP_OFFSET+0x07	/* just for statistic */
# define ERR_DSP_MALLOC_ERR	DSP_OFFSET+0x08	/* reset */
# define ERR_DSP_D_TIMEOUT	DSP_OFFSET+0x09	/* reset */
# define ERR_DSP_LOST		DSP_OFFSET+0x10	/* just for statistic */
# define ERR_DSP_INIT        DSP_OFFSET+0x11 /* reset */
# define ERR_DSP_OVERLOAD    DSP_OFFSET+0x12 /* just for statistic */
# define ERR_DSP_WDT_ADD     DSP_OFFSET+0x13 /* just for statistic */

# define ERR_DSP_API         DSP_OFFSET+0x14 /* dsp api errors */
# define ERR_DSP_API_COMMON  DSP_OFFSET+0x15 /* dsp api common errors */
# define ERR_DSP_TONES       DSP_OFFSET+0x16 /* dsp tones errors */
# define ERR_DSP_CTRL        DSP_OFFSET+0x17 /* dsp ctrl errors */
# define ERR_DSP_DIM         DSP_OFFSET+0x18 /* dsp dim errors */
# define ERR_DSP_NW          DSP_OFFSET+0x19 /* dsp nw errors */
# define ERR_DSP_PKMGR       DSP_OFFSET+0x20 /* dsp pkmgr errors */
# define ERR_DSP_FATAL       DSP_OFFSET+0x21+X_FAT /* dsp fatal error */
# define ERR_DSP_RTP         DSP_OFFSET+0x22 /* dsp rtp application error */
# define ERR_DSP_HW_UTILS    DSP_OFFSET+0x23 /* dsp hw utils error */
# define ERR_DSP_VoIP_PCU_RELOAD DSP_OFFSET+0x24+X_FAT /* PCU reset because of too many unssuccessful recovery */

/*************************************/
/*          Error codes for Ethernet */
/*************************************/
#define ERR_ETH_ERR              ETH_OFFSET+0x00 /* just for statistic */
#define ERR_ETH_INIT_ERR         ETH_OFFSET+0x01 /* just for statistic */
#define ERR_ETH_DATA_ERR         ETH_OFFSET+0x02 /* just for statistic */
#define ERR_ETH_RTDB_ERR         ETH_OFFSET+0x03 /* just for statistic */
#define ERR_ETH_INIT_STAT        ETH_OFFSET+0x04 /* just for statistic */
#define ERR_ETH_RTDB_TRIG        ETH_OFFSET+0x05 /* just for statistic */
#define ERR_ETH_TRIG_ERR         ETH_OFFSET+0x06 /* just for statistic */
#define ERR_ETH_STAT_INFO        ETH_OFFSET+0x07 /* just for statistic */
#define ERR_ETH_API_ERR          ETH_OFFSET+0x08 /* just for statistic */
#define ERR_ETH_RESTART_ERR      ETH_OFFSET+0x09 /* just for statistic */
#define ERR_ETH_OVLD_ERR         ETH_OFFSET+0x0A /* just for statistic */
#define ERR_ETH_PIPC_ERR         ETH_OFFSET+0x0B+X_FAT /* reset */
#define ERR_ETH_INTF_RST         ETH_OFFSET+0x0C+X_FAT /* reset */

/*************************************/
/*          Error codes for Ethernet */
/*************************************/
#define ERR_NTP_PIPC_ECHO	NTP_OFFSET+0x00
#define ERR_NTP_PIPC_SEND	NTP_OFFSET+0x01
#define ERR_NTP_PIPC_RECEIVE	NTP_OFFSET+0x02
#define ERR_NTP_PIPC_REGISTER	NTP_OFFSET+0x03
#define ERR_NTP_CONFIG		NTP_OFFSET+0x04
#define ERR_NTP_CLOCK_SET	NTP_OFFSET+0x05
#define ERR_NTP_TIMEZONE	NTP_OFFSET+0x06
#define ERR_NTP_TIME_SET	NTP_OFFSET+0x07
#define ERR_NTP_STATUS		NTP_OFFSET+0x08

/************************************************************/
/*          Error codes for DRH - Diagnostic Report Handler */
/************************************************************/
#define ERR_DRH_INP_ARG		DRH_OFFSET+0x01
#define ERR_DRH_ILL_ERR_PRI	DRH_OFFSET+0x02
#define ERR_DRH_MSG_TYP		DRH_OFFSET+0x03
#define ERR_DRH_ALLOC		DRH_OFFSET+0x04
#define ERR_DRH_QUE_FULL	DRH_OFFSET+0x05
#define ERR_DRH_T_CREATE	DRH_OFFSET+0x06
#define ERR_DRH_RTDB		DRH_OFFSET+0x07
#define ERR_DRH_CONF_CHG	DRH_OFFSET+0x08
#define ERR_DRH_REGEXP		DRH_OFFSET+0x09
#define ERR_DRH_LIB		DRH_OFFSET+0x0A
#define ERR_DRH_QUERY		DRH_OFFSET+0x0B
#define ERR_DRH_NULLARG		DRH_OFFSET+0x0C
#define ERR_DRH_DB_ERRCOD	DRH_OFFSET+0x0D
#define ERR_DRH_DB		DRH_OFFSET+0x0E
#define ERR_DRH_MEAS_NREG	DRH_OFFSET+0x0F
#define ERR_DRH_MEAS_ADD	DRH_OFFSET+0x10
#define ERR_DRH_MEAS_DEL	DRH_OFFSET+0x11
#define ERR_DRH_MEAS_NOMEM	DRH_OFFSET+0x12
#define ERR_DRH_MEAS_DUP	DRH_OFFSET+0x13
#define ERR_DRH_CLOCK		DRH_OFFSET+0x14
#define ERR_DRH_SM_CREATE	DRH_OFFSET+0x15
#define ERR_DRH_SM_P		DRH_OFFSET+0x16
#define ERR_DRH_SM_V		DRH_OFFSET+0x17
#define ERR_DRH_MSGRCV		DRH_OFFSET+0x18
#define ERR_DRH_HAM		DRH_OFFSET+0x19
#define ERR_DRH_FORK		DRH_OFFSET+0x1A
#define ERR_DRH_START		DRH_OFFSET+0x1B + X_INI         /* init message	*/
#define ERR_DRH_SIG		DRH_OFFSET+0x1C
#define ERR_DRH_MSG_SEND	DRH_OFFSET+0x1D
#define ERR_DRH_SNMPX		DRH_OFFSET+0x1E


/*************************************/
/*          Error codes for SDL      */
/*************************************/
# define ERR_SDL_MEMORY_ALLOC   SDL_OFFSET+0x201+MSG_NOFILT+X_FAT /* reset */
# define ERR_SDL_MSGQSEND	SDL_OFFSET+0x202+MSG_NOFILT+X_FAT /* reset */
# define ERR_SDL_MEMORY_FREE    SDL_OFFSET+0x301+MSG_NOFILT+X_FAT /* reset */
# define ERR_SDL_Q_CREATE_EXTE		SDL_OFFSET+0x01  /* info  */
# define ERR_SDL_Q_CREATE_EXTP  	SDL_OFFSET+0x02  /* info  */
# define ERR_SDL_Q_CREATE_INT_TP	SDL_OFFSET+0x03  /* info  */
# define ERR_SDL_Q_CREATE_INT_TB	SDL_OFFSET+0x04  /* info  */
# define ERR_SDL_Q_CREATE_INT_TI	SDL_OFFSET+0x05  /* info  */
# define ERR_SDL_Q_CREATE_TIME		SDL_OFFSET+0x06  /* info  */
# define ERR_SDL_Q_DELETE_MULTI_TI	SDL_OFFSET+0x10  /* info  */
# define ERR_SDL_Q_DELETE_MONO_TI	SDL_OFFSET+0x11  /* info  */
# define ERR_SDL_Q_IDENT_EXTE		SDL_OFFSET+0x20  /* info  */
# define ERR_SDL_Q_IDENT_EXTP 	 	SDL_OFFSET+0x21  /* info  */
# define ERR_SDL_Q_IDENT_EXTT		SDL_OFFSET+0x22  /* info  */
# define ERR_SDL_Q_IDENT_PROCED		SDL_OFFSET+0x23  /* info  */
# define ERR_SDL_Q_IDENT_MULTI_TI	SDL_OFFSET+0x24  /* info  */
# define ERR_SDL_Q_IDENT_MONO_TI	SDL_OFFSET+0x25  /* info  */
# define ERR_SDL_Q_IDENT_TP		SDL_OFFSET+0x26  /* info  */
# define ERR_SDL_Q_IDENT_TB		SDL_OFFSET+0x27  /* info  */
# define ERR_SDL_Q_RECEIVE_EXTE		SDL_OFFSET+0x30  /* info  */
# define ERR_SDL_Q_RECEIVE_EXTP		SDL_OFFSET+0x31  /* info  */
# define ERR_SDL_Q_SEND_EXTT		SDL_OFFSET+0x40  /* info  */
# define ERR_SDL_T_CREATE_EXTE		SDL_OFFSET+0x50  /* info  */
# define ERR_SDL_T_CREATE_EXTP_TIP	SDL_OFFSET+0x51  /* info  */
# define ERR_SDL_T_CREATE_EXTP_TB	SDL_OFFSET+0x52  /* info  */
# define ERR_SDL_T_CREATE_INT_TB	SDL_OFFSET+0x53  /* info  */
# define ERR_SDL_T_CREATE_INT_TP	SDL_OFFSET+0x54  /* info  */
# define ERR_SDL_T_CREATE_INT_TI	SDL_OFFSET+0x55  /* info  */
# define ERR_SDL_T_CREATE_TIME		SDL_OFFSET+0x56  /* info  */
# define ERR_SDL_T_DELETE_MULTI_TI	SDL_OFFSET+0x60  /* info  */
# define ERR_SDL_T_DELETE_MONO_TI	SDL_OFFSET+0x61  /* info  */
# define ERR_SDL_T_GETREG_TI_P2		SDL_OFFSET+0x70  /* info  */
# define ERR_SDL_T_GETREG_TI_P1		SDL_OFFSET+0x71  /* info  */
# define ERR_SDL_T_GETREG_TI_P		SDL_OFFSET+0x72  /* info  */
# define ERR_SDL_T_START_MULTI_TI	SDL_OFFSET+0x90  /* info  */
# define ERR_SDL_T_START_MONO_TI	SDL_OFFSET+0x91  /* info  */
# define ERR_SDL_T_START_EXTE		SDL_OFFSET+0x92  /* info  */
# define ERR_SDL_T_START_EXTP		SDL_OFFSET+0x93  /* info  */
# define ERR_SDL_T_START_EXTP_TB	SDL_OFFSET+0x94  /* info  */
# define ERR_SDL_T_START_TB		SDL_OFFSET+0x95  /* info  */
# define ERR_SDL_T_START_TP		SDL_OFFSET+0x96  /* info  */
# define ERR_SDL_T_START_TIME		SDL_OFFSET+0x97  /* info  */
# define ERR_SDL_T_SUSPEND_EXTE		SDL_OFFSET+0x100  /* info  */
# define ERR_SDL_T_SUSPEND_EXTP		SDL_OFFSET+0x101  /* info  */
# define ERR_SDL_T_SUSPEND_NODE		SDL_OFFSET+0x102  /* info  */
# define ERR_SDL_WRONG_MEMORY_TYPE	SDL_OFFSET+0x103  /* info  */
# define ERR_SDL_SAVE_QUEUE_FULL	SDL_OFFSET+0x104  /* info  */
# define ERR_SDL_WRONG_POINTER	        SDL_OFFSET+0x105  /* info  */
# define ERR_SDL_FNCT_STAT_NOT_ACTIVE   SDL_OFFSET+0x106  /* info  */
# define ERR_SDL_FNCT_STAT_ACTIVE       SDL_OFFSET+0x107  /* info  */
# define ERR_SDL_FNCT_STAT_DEACTIVATED  SDL_OFFSET+0x108  /* info  */
# define ERR_SDL_FNCT_STAT_CHANGE       SDL_OFFSET+0x109  /* info  */
# define ERR_SDL_RN_GETSEG		SDL_OFFSET+0x200 /* reset */
# define ERR_SDL_RN_RETSEG		SDL_OFFSET+0x300 /* reset */


/*************************************/
/*          Error codes for DSS1     */
/*************************************/
#define ERR_DSS1_BUFFER_FULL		DSS1_OFFSET+0x01  /* info  */


/*************************************/
/*          Error codes for V5.2     */
/*************************************/
#define ERR_V52_V5LINKID_MISMATCH	V52_OFFSET+0x01  /* info  */


/*************************************/
/*          Error codes for TRACER   */
/*************************************/
# define ERR_TRC_RN_GETSEG	TRC_OFFSET+0x00+X_FAT /* reset */
# define ERR_TRC_RN_RETSEG	TRC_OFFSET+0x01+X_FAT /* reset */
# define ERR_TRC_MALLOC		TRC_OFFSET+0x02+X_FAT /* reset */
# define ERR_TRC_FREE		TRC_OFFSET+0x03+X_FAT /* reset */
# define ERR_TRC_ACTIVATED	TRC_OFFSET+0x04+MSG_NOFILT /* info */
# define ERR_TRC_DEACTIVATED	TRC_OFFSET+0x05+MSG_NOFILT /* info */
# define ERR_TRC_COPY		TRC_OFFSET+0x06 /* info */

/************************************************/
/* DTRC - diag tracer and diag dump error codes */
/************************************************/
# define ERR_DTRC_SAV_DTRC	DTRC_OFFSET+0x01 /* info  */
# define ERR_DTRC_POINTERS	DTRC_OFFSET+0x02 /* info  */
# define ERR_DTRC_SAV_DDMP	DTRC_OFFSET+0x10 /* info  */
# define ERR_DTRC_SAV_DSDL	DTRC_OFFSET+0x20 /* info  */
# define ERR_DTRC_INIT_VAR      DTRC_OFFSET+0x30 /* info  */

/******* STRC - sig tracer error codes */
# define ERR_STRC_T_CREATE      STRC_OFFSET+0x30+X_FAT /* reset */
# define ERR_STRC_T_START       STRC_OFFSET+0x31+X_FAT /* reset */
# define ERR_STRC_Q_CREATE      STRC_OFFSET+0x32+X_FAT /* reset */
# define ERR_STRC_Q_SEND        STRC_OFFSET+0x33 	/* info */
# define ERR_STRC_Q_RECEIVE     STRC_OFFSET+0x34+X_FAT /* info  */
# define ERR_STRC_RN_GETSEG     STRC_OFFSET+0x35+X_FAT /* reset */
# define ERR_STRC_RN_RETSEG     STRC_OFFSET+0x36+X_FAT /* reset */
# define ERR_STRC_OPEN_F        STRC_OFFSET+0x37 /* info  */
# define ERR_STRC_STAT_F        STRC_OFFSET+0x38 /* info  */


/*************************************/
/*          Error codes for DIAG     */
/*************************************/

# define ERR_DIAG_SM_P		DIAG_OFFSET+0x00 /* info */
# define ERR_DIAG_SM_CREATE	DIAG_OFFSET+0x01 /* info */
# define ERR_DIAG_T_CREATE	DIAG_OFFSET+0x02 /* info */
# define ERR_DIAG_Q_CREATE	DIAG_OFFSET+0x03 /* info */
# define ERR_DIAG_T_RESTART	DIAG_OFFSET+0x04 /* info */
# define ERR_DIAG_RN_GETSEG	DIAG_OFFSET+0x05 /* info */
# define ERR_DIAG_RN_RETSEG	DIAG_OFFSET+0x06 /* info */
# define ERR_DIAG_Q_SEND	DIAG_OFFSET+0x07 /* info */
# define ERR_DIAG_DB_ACCESS	DIAG_OFFSET+0x08 /* info */
# define ERR_DIAG_T_START	DIAG_OFFSET+0x09 /* info */
# define ERR_DIAG_DMQ_WR_IX	DIAG_OFFSET+0x0a /* info */
# define ERR_DIAG_DMQ_RD_IX	DIAG_OFFSET+0x0b /* info */
# define ERR_DIAG_SM_V		DIAG_OFFSET+0x0c /* info */
# define ERR_DIAG_CHANGE_DIR	DIAG_OFFSET+0x0d /* info */
# define ERR_DIAG_FOPEN		DIAG_OFFSET+0x0e /* info */
# define ERR_DIAG_FWRITE	DIAG_OFFSET+0x0f /* info */
# define ERR_DIAG_FCLOSE	DIAG_OFFSET+0x10 /* info */
# define ERR_DIAG_MSG_LEN	DIAG_OFFSET+0x11 /* info */
# define ERR_DIAG_MSG_PTR	DIAG_OFFSET+0x12 /* info */
# define ERR_DIAG_MSG_TYP	DIAG_OFFSET+0x13 /* info */
# define ERR_DIAG_RTDB		DIAG_OFFSET+0x14 /* info */
# define ERR_DIAG_CONNECT       DIAG_OFFSET+0x15 /* info */
# define ERR_DIAG_CLNT_CREATE   DIAG_OFFSET+0x16 /* info */
# define ERR_DIAG_CLNT_CALL     DIAG_OFFSET+0x17 /* info */
# define ERR_DIAG_Q_IDENT    	DIAG_OFFSET+0x18 /* info */
# define ERR_DIAG_OVERLOAD	DIAG_OFFSET+0x19 /* info */
# define ERR_DIAG_MSG_TIME	DIAG_OFFSET+0x1a /* info */
# define ERR_DIAG_STAT_VFS      DIAG_OFFSET+0x1b /* info */
# define ERR_DIAG_STAT_F        DIAG_OFFSET+0x1c /* info */
# define ERR_DIAG_RENAME        DIAG_OFFSET+0x1d /* info */
# define ERR_DIAG_DSKOVR        DIAG_OFFSET+0x1e /* info */
# define ERR_DIAG_DMQFUL        DIAG_OFFSET+0x1f /* info */
# define ERR_DIAG_Q_SMP		DIAG_OFFSET+0x20 /* info */
# define ERR_DIAG_RSLT_LEN	DIAG_OFFSET+0x21 /* info */
# define ERR_DIAG_RSLT_PTR	DIAG_OFFSET+0x22 /* info */
# define ERR_DIAG_RSLT_TYP	DIAG_OFFSET+0x23 /* info */
# define ERR_DIAG_DSKLOW	DIAG_OFFSET+0x24 /* info */
# define ERR_DIAG_DSKMIN	DIAG_OFFSET+0x25 /* info */
# define ERR_DIAG_DMQ_RD_PT	DIAG_OFFSET+0x26 /* info */
# define ERR_DIAG_DMQ_WR_PT	DIAG_OFFSET+0x27 /* info */
# define ERR_DIAG_DMQ_CVA_FUL   DIAG_OFFSET+0x28 /* info */
# define ERR_DIAG_Q_DELETE      DIAG_OFFSET+0x29 /* info */
# define ERR_DIAG_T_DELETE      DIAG_OFFSET+0x2A /* info */
# define ERR_DIAG_INIT_COMBO    DIAG_OFFSET+0x2B /* info */
# define ERR_DIAG_DGTAB         DIAG_OFFSET+0x2C /* info */
# define ERR_DIAG_MFSIG         DIAG_OFFSET+0x2D /* info */
# define ERR_DIAG_QURGENT       DIAG_OFFSET+0x2E /* info */
# define ERR_DIAG_GETBUF        DIAG_OFFSET+0x2F /* info */
# define ERR_DIAG_TARIFFINIT    DIAG_OFFSET+0x30 /* info */
# define ERR_DIAG_BILL_LEN	DIAG_OFFSET+0x31 /* info */
# define ERR_DIAG_Q_COUNT	DIAG_OFFSET+0x32 /* info */
# define ERR_DIAG_FLTIND	DIAG_OFFSET+0x33 /* info */
# define ERR_DIAG_MESSAGE_REPEATED	DIAG_OFFSET+0x34 /* info */
# define ERR_DIAG_DGCOM         DIAG_OFFSET+0x35 /* info */
# define ERR_DIAG_DMQ_INIT      DIAG_OFFSET+0x36 /* info */
# define ERR_DIAG_BILL_FULL     DIAG_OFFSET+0x37 /* info */
# define ERR_DIAG_T_CREATE_WDFS DIAG_OFFSET+0x38 /* info */
# define ERR_DIAG_T_START_WDFS  DIAG_OFFSET+0x39 /* info */
# define ERR_DIAG_EV_SEND_WDFS	DIAG_OFFSET+0x3A /* info */
# define ERR_DIAG_EV_RECV_WDFS	DIAG_OFFSET+0x3B /* info */
# define ERR_DIAG_T_IDENT       DIAG_OFFSET+0x3C /* info */
# define ERR_DIAG_SENDTO        DIAG_OFFSET+0x3D /* info */
# define ERR_DIAG_SOCKET        DIAG_OFFSET+0x3E /* info */
# define ERR_DIAG_DB_SPD_ERROR	DIAG_OFFSET+0x3F /* info */
# define ERR_DIAG_SVC_RUN       DIAG_OFFSET+0x40 /* info */
# define ERR_DIAG_DMQ_DESC      DIAG_OFFSET+0x41 /* info */
# define ERR_DIAG_DMQ_SM_P      DIAG_OFFSET+0x42 /* info */
# define ERR_DIAG_DMQ_SM_V      DIAG_OFFSET+0x43 /* info */
# define ERR_DIAG_DMQ_CNT       DIAG_OFFSET+0x44 /* info */
# define ERR_DIAG_CREATE_F      DIAG_OFFSET+0x45 /* info */
# define ERR_DIAG_OPEN_F        DIAG_OFFSET+0x46 /* info */
# define ERR_DIAG_WRITE_F       DIAG_OFFSET+0x47 /* info */
# define ERR_DIAG_CLOSE_F       DIAG_OFFSET+0x48 /* info */
# define ERR_DIAG_MALLOC        DIAG_OFFSET+0x49 /* info */
# define ERR_DIAG_TM_GET        DIAG_OFFSET+0x4A /* info */
# define ERR_DIAG_LSEEK_F       DIAG_OFFSET+0x4B /* info */
# define ERR_DIAG_READ_F        DIAG_OFFSET+0x4C /* info */
# define ERR_DIAG_SWITCH_CH     DIAG_OFFSET+0x4D /* info */
# define ERR_DIAG_SWITCH        DIAG_OFFSET+0x4E /* info */
# define ERR_DIAG_MAKE_DIR      DIAG_OFFSET+0x4F /* info */
# define ERR_DIAG_REMOVE        DIAG_OFFSET+0x50 /* info */
# define ERR_DIAG_RTC_UPDATE    DIAG_OFFSET+0x51 /* info */
# define ERR_DIAG_SWRTC_ERR     DIAG_OFFSET+0x52 /* info */
# define ERR_DIAG_HWRTC_ERR     DIAG_OFFSET+0x53 /* info */
# define ERR_DIAG_HWSWRTC_ERR   DIAG_OFFSET+0x54 /* info */
# define ERR_DIAG_FILE_SYS_OK   DIAG_OFFSET+0x55+MSG_NOFILT /* info */
# define ERR_DIAG_REMOVE_F      DIAG_OFFSET+0x56 /* info */
# define ERR_DIAG_MOVE_F        DIAG_OFFSET+0x57 /* info */
# define ERR_DIAG_EV_SEND       DIAG_OFFSET+0x58 /* info */
# define ERR_DIAG_Q_RECEIVE	DIAG_OFFSET+0x59 /* info */
# define ERR_DIAG_ALR_CLR	DIAG_OFFSET+0x5A /* info */
# define ERR_DIAG_PING_MSG_LEN  DIAG_OFFSET+0x5B /* info */
# define ERR_DIAG_SWRTC_UPDATA  DIAG_OFFSET+0x5C /* info */
# define ERR_DIAG_RPC_RTC  	DIAG_OFFSET+0x5D /* info */
# define ERR_DIAG_T_MODE        DIAG_OFFSET+0x5E /* info */
# define ERR_DIAG_EV_RECEIVE    DIAG_OFFSET+0x5F /* info */
# define ERR_DIAG_OVERHEAT      DIAG_OFFSET+0x60 /* info */
# define ERR_DIAG_EV_RECV       DIAG_OFFSET+0x61 /* info */
# define ERR_DIAG_AXM_ALARM     DIAG_OFFSET+0x62 /* info */
# define ERR_DIAG_WARM_UP    	DIAG_OFFSET+0x63 /* info */
# define ERR_DIAG_MENU_RUN      DIAG_OFFSET+0x64 /* info */
# define ERR_DIAG_ILL_MENU_NR   DIAG_OFFSET+0x65 /* info */
# define ERR_DIAG_BOARD_POS   	DIAG_OFFSET+0x66 /* info */
# define ERR_DIAG_IDENT_MSG   	DIAG_OFFSET+0x67 /* info */
# define ERR_DIAG_WRNG_ATM_ALM  DIAG_OFFSET+0x68 /* info */
# define ERR_DIAG_SGx_RTCUPDATE DIAG_OFFSET+0x69 /* info */
# define ERR_DIAG_WRONG_PARAM   DIAG_OFFSET+0x6A /* info */
# define ERR_DIAG_DE_CTRL       DIAG_OFFSET+0x6B /* info */
# define ERR_DIAG_DRV           DIAG_OFFSET+0x6C /* info */
# define ERR_DIAG_TM_EVAFTER	DIAG_OFFSET+0x6D /* info */
# define ERR_DIAG_PING_INIT	DIAG_OFFSET+0x6E /* info */
# define ERR_DIAG_PING_SEND	DIAG_OFFSET+0x6F /* info */
# define ERR_DIAG_RTC_MSG   	DIAG_OFFSET+0x70 /* info */
# define ERR_DIAG_SWITCH_CB     DIAG_OFFSET+0x71 /* info */
# define ERR_DIAG_DE_CNTRL      DIAG_OFFSET+0x72 /* info */
# define ERR_DIAG_ATMSW_ALM_OVL DIAG_OFFSET+0x73 /* info */
# define ERR_DIAG_ATMSW_ALM_OVL DIAG_OFFSET+0x73 /* info */
# define ERR_DIAG_SACTEST       DIAG_OFFSET+0x74 /* info */
# define ERR_DIAG_AUXI_RTCUPDATE DIAG_OFFSET+0x75 /* info */
# define ERR_DIAG_TASK_BLOCKED  DIAG_OFFSET+0x76 /* info */
# define ERR_DIAG_HWRTC_UPDATE  DIAG_OFFSET+0x77 /* info */
# define ERR_DIAG_MSG_REJECT    DIAG_OFFSET+0x78 /* info */
# define ERR_DIAG_IPSUB_OVERFLOW DIAG_OFFSET+0x79 /* info */
# define ERR_DIAG_OBJ_ID        DIAG_OFFSET+0x7A /* info */
# define ERR_DIAG_EXTSPT_FAIL	DIAG_OFFSET+0x7B /* info */
# define ERR_DIAG_WRONG_DSP_INDEX DIAG_OFFSET+0x7C /* info */
# define ERR_DIAG_TIMEOUT	DIAG_OFFSET+0x7D /* info */
# define ERR_DIAG_TESTIM        DIAG_OFFSET+0x7E /* info */
# define ERR_DIAG_CPU_LOAD      DIAG_OFFSET+0x7F + X_INF /* info */
# define ERR_DIAG_IMA           DIAG_OFFSET+0x80 /* info */
# define ERR_DIAG_BOOT_UNZIP    DIAG_OFFSET+0x81 /* info */
# define ERR_DIAG_ETH_LINK      DIAG_OFFSET+0x82 /* info */ 
# define ERR_DIAG_CDA_ID_MSMTCH DIAG_OFFSET+0x83 /* info */
# define ERR_DIAG_DFS_MOUNT     DIAG_OFFSET+0x84 /* info */
# define ERR_DIAG_REM_RELD_EXP  DIAG_OFFSET+0x85 /* info */
# define ERR_DIAG_REM_RELOADED  DIAG_OFFSET+0x86 /* info */
# define ERR_DIAG_REM_RESET     DIAG_OFFSET+0x87 /* info */
# define ERR_DIAG_REM_NOT_RESP  DIAG_OFFSET+0x88 /* info */
# define ERR_DIAG_REM_READY     DIAG_OFFSET+0x89 /* info */
# define ERR_DIAG_ATMSW         DIAG_OFFSET+0x8A /* info */
# define ERR_DIAG_MEM_FREE      DIAG_OFFSET+0x8B /* info */
# define ERR_DIAG_STM1          DIAG_OFFSET+0x8C /* info */
# define ERR_DIAG_ATM25         DIAG_OFFSET+0x8D /* info */
# define ERR_DIAG_WD_CREATE	DIAG_OFFSET+0x8E /* info */
# define ERR_DIAG_SRV_CLNT_COMM DIAG_OFFSET+0x8F /* info */
# define ERR_DIAG_MSG_ERR	DIAG_OFFSET+0x90 /* info */
# define ERR_DIAG_TRQ_INIT      DIAG_OFFSET+0x91 /* info */
# define ERR_DIAG_MEM_LOAD      DIAG_OFFSET+0x92 + X_INF /* info */
# define ERR_DIAG_IOCTL         DIAG_OFFSET+0x93 /* info */
# define ERR_DIAG_IPMI		DIAG_OFFSET+0x94 /* info */
# define ERR_DIAG_MEM_LOAD_RESET DIAG_OFFSET+0x95 + X_FAT /* reset */
# define ERR_DIAG_RTCP      	DIAG_OFFSET+0x96 /* info */
# define ERR_DIAG_DL_OPEN       DIAG_OFFSET+0x97 /* info */
# define ERR_DIAG_DL_SYM        DIAG_OFFSET+0x98 /* info */
# define ERR_DIAG_RPRT_ERR      DIAG_OFFSET+0x99 /* info */
# define ERR_DIAG_ERR           DIAG_OFFSET+0x9A /* info */
# define ERR_DIAG_EQUIP         DIAG_OFFSET+0x9B /* info */
# define ERR_DIAG_RTCP_OK       DIAG_OFFSET+0x9C /* info */
# define ERR_DIAG_RTCP_ERROR    DIAG_OFFSET+0x9D /* info */
# define ERR_DIAG_RTCP_WARNING  DIAG_OFFSET+0x9E /* info */
# define ERR_DIAG_ETH_LATE_COLL DIAG_OFFSET+0x9F /* info */
# define ERR_DIAG_ETH_UNDERRUN DIAG_OFFSET+0xA0 /* info */
# define ERR_DIAG_ETH_TX_MEM_ERR DIAG_OFFSET+0xA1 /* info */
# define ERR_DIAG_ETH_BUSY_ERR DIAG_OFFSET+0xA2 /* info */
# define ERR_DIAG_ETH_CRC_ERR DIAG_OFFSET+0xA3 /* info */
# define ERR_DIAG_ETH_OVERRUN DIAG_OFFSET+0xA4 /* info */
# define ERR_DIAG_ETH_RX_COLLISION DIAG_OFFSET+0xA5 /* info */
# define ERR_DIAG_ETH_RX_MEM_ERR DIAG_OFFSET+0xA6 /* info */
# define ERR_DIAG_ETH_TX_RL DIAG_OFFSET+0xA7 /* info */
# define ERR_DIAG_ETH_TX_RC DIAG_OFFSET+0xA8 /* info */
# define ERR_DIAG_ETH_TX_DEF DIAG_OFFSET+0xA9 /* info */
# define ERR_DIAG_SYS_PARAM     DIAG_OFFSET+0xAA /* info */
# define ERR_DIAG_SYS_PARAM_OK  DIAG_OFFSET+0xAB /* info */
# define ERR_DIAG_PEGG          DIAG_OFFSET+0xAC /* Ping egg connection diagnostics */
# define ERR_DIAG_PEGG_OK       DIAG_OFFSET+0xAD /* Ping egg connection diagnostics */

/***************************************************/
/*          Error codes for START and RECOVERY     */
/***************************************************/

# define ERR_SR_T_CREATE	SR_OFFSET+0x00+X_FAT	/* reset */
# define ERR_SR_T_START		SR_OFFSET+0x01+X_FAT	/* reset */
# define ERR_SR_Q_CREATE	SR_OFFSET+0x02+X_FAT	/* reset */
# define ERR_SR_Q_RECEIVE	SR_OFFSET+0x03+X_FAT	/* reset */
# define ERR_SR_RN_RETSEG	SR_OFFSET+0x04+X_FAT  /* reset */
# define ERR_SR_WDT_CREATE	SR_OFFSET+0x05+X_FAT	/* reset */
# define ERR_SR_WDT_START	SR_OFFSET+0x06+X_FAT	/* reset */
# define ERR_SR_APP_CREATE	SR_OFFSET+0x07+X_FAT	/* reset */
# define ERR_SR_APP_START	SR_OFFSET+0x08+X_FAT	/* reset */
# define ERR_SR_PSH_FAIL	SR_OFFSET+0x09+X_FAT	/* reset */
# define ERR_SR_DB	        SR_OFFSET+0x0a	/* info */
# define ERR_SR_Q_SEND	        SR_OFFSET+0x0b	/* info */
# define ERR_SR_DB_OOSI	        SR_OFFSET+0x0c	/* info */
# define ERR_SR_DB_ADT	        SR_OFFSET+0x0d	/* info */
# define ERR_SR_DB_SUPPLY	SR_OFFSET+0x0e	/* info */
# define ERR_SR_WRONG_SPD	SR_OFFSET+0x0f+MSG_NOFILT	/* info */
# define ERR_SR_WRONG_MEASURE	SR_OFFSET+0x10	/* info */
# define ERR_SR_INIT_BOARD	SR_OFFSET+0x11	/* info */
# define ERR_SR_INIT_HSCX	SR_OFFSET+0x12	/* info */
# define ERR_SR_INIT_DIG_PORT	SR_OFFSET+0x13	/* info */
# define ERR_SR_INIT_CLA	SR_OFFSET+0x14	/* info */
# define ERR_SR_RN_GETSEG	SR_OFFSET+0x15+X_FAT	/* reset */
# define ERR_SR_SYNC_VOL	SR_OFFSET+0x16	/* info */
# define ERR_SR_MEM		SR_OFFSET+0x17	/* info */
# define ERR_SR_PR_IDENT	SR_OFFSET+0x18	/* info */
# define ERR_SR_CALLBLK		SR_OFFSET+0x19	/* info */
# define ERR_SR_DIAGSTS		SR_OFFSET+0x1a	/* info */
# define ERR_SR_INIT_SWITCH	SR_OFFSET+0x1b	/* info */
# define ERR_SR_INIT_TDM        SR_OFFSET+0x1c  /* info */
# define ERR_SR_PPP_BUSY        SR_OFFSET+0x1d  /* info */
# define ERR_SR_INIT_CLK        SR_OFFSET+0x1e  /* info */
# define ERR_SR_INIT_CDA        SR_OFFSET+0x1f+MSG_NOFILT  /* info */
# define ERR_SR_INIT_SIGNAL     SR_OFFSET+0x20  /* reset */
# define ERR_SR_Q_DELETE        SR_OFFSET+0x21  /* info */
# define ERR_SR_INIT_PORT       SR_OFFSET+0x22  /* info */
# define ERR_SR_OLD_TASK        SR_OFFSET+0x23+MSG_NOFILT  /* info */
# define ERR_SR_NEW_TASK        SR_OFFSET+0x24+MSG_NOFILT  /* info */
# define ERR_SR_CDA_OLD_TASK    SR_OFFSET+0x25+MSG_NOFILT  /* info */
# define ERR_SR_CDA_NEW_TASK    SR_OFFSET+0x26+MSG_NOFILT  /* info */
# define ERR_SR_WRONG_ENTRY     SR_OFFSET+0x27  /* reset */
# define ERR_SR_SYNC_SOURCE     SR_OFFSET+0x28  /* info */
# define ERR_SR_CDA_BIN_FILE    SR_OFFSET+0x29  /* info */
# define ERR_SR_WRONG_EXIT      SR_OFFSET+0x2a+X_FAT  /* reset */
# define ERR_SR_SAC_INIT        SR_OFFSET+0x2b  /* info */
# define ERR_SR_LOC_CALLBLK     SR_OFFSET+0x2c  /* info */
# define ERR_SR_TRANS_CALLBLK   SR_OFFSET+0x2d  /* info */
# define ERR_SR_RN0SEG_CALLBLK  SR_OFFSET+0x2e  /* info */
# define ERR_SR_PSOS_CALLBLK    SR_OFFSET+0x2f  /* info */
# define ERR_SR_RNCB_ERROR      SR_OFFSET+0x30  /* info */
# define ERR_SR_SYSERRINT_FULL  SR_OFFSET+0x31  /* info */
# define ERR_SR_WRONG_SYSERR_PT SR_OFFSET+0x32  /* info */
# define ERR_SR_SYSERR_FROM_INT SR_OFFSET+0x33  /* info */
# define ERR_SR_RESET_CDA_FROM_MN SR_OFFSET+0x34  /* info */
# define ERR_SR_STATISTIC       SR_OFFSET+0x35+MSG_NOFILT  /* info */
# define ERR_SR_RESET_VIA_WDT   SR_OFFSET+0x36  /* info */
# define ERR_SR_DTRC_COPY       SR_OFFSET+0x37  /* info */
# define ERR_SR_INT_PER_TICK    SR_OFFSET+0x38  /* info */
# define ERR_SR_INT_PER_PROC    SR_OFFSET+0x39  /* info */
# define ERR_SR_RECONF_CDA      SR_OFFSET+0x3a  /* info */
# define ERR_SR_INIT_NET        SR_OFFSET+0x3b  /* reset */
# define ERR_SR_INIT_PASSWD     SR_OFFSET+0x3c  /* reset */
# define ERR_SR_PREPARE_CDX     SR_OFFSET+0x3d  /* info */
# define ERR_SR_WRONG_SIGNAL    SR_OFFSET+0x3e  /* info */
# define ERR_SR_T_RESTART       SR_OFFSET+0x3f  /* info */
# define ERR_SR_REBOOT_HOOK     SR_OFFSET+0x40  /* info */
# define ERR_SR_STACK_LIMIT     SR_OFFSET+0x41  /* info */


/***************************************************/
/*          Error codes for MMU                    */
/***************************************************/

# define ERR_MMU_MAP_CREATE     MMU_OFFSET+0x00 /* info */
# define ERR_MMU_MAP_SETATTR    MMU_OFFSET+0x01 /* info */
# define ERR_MMU_MAP_TASK       MMU_OFFSET+0x02 /* info */
# define BBRAM_WRITE_ERROR      MMU_OFFSET+0x03 /* info */
# define SRAM_WRITE_ERROR       MMU_OFFSET+0x04 /* info */
# define ERR_MMU_EXCEPTION      MMU_OFFSET+0x05+X_FAT /* reset */
# define ERR_MMU_PROTECT        MMU_OFFSET+0x06 /* info */




/*************************************/
/*          Error codes for RTDB     */
/*************************************/

# define ERR_RTDB_NO_MEMORY		RTDB_OFFSET+0x00+X_FAT /* instalation + reset */
# define ERR_RTDB_WRONG_DATA_TYPE 	RTDB_OFFSET+0x01+X_FAT /* instalation + reset */
# define ERR_RTDB_TABLE_RECOVERY 	RTDB_OFFSET+0x02+X_FAT /* instalation + reset */
# define ERR_RTDB_SMV_RTIX 		RTDB_OFFSET+0x03 /* info 		*/
# define ERR_RTDB_SMP_RTIX 		RTDB_OFFSET+0x04 /* info 		*/
# define ERR_RTDB_GET_BCKPDIR 		RTDB_OFFSET+0x05+X_FAT /* reset 		*/
# define ERR_RTDB_CHANGE_BCKPDIR	RTDB_OFFSET+0x06+X_FAT /* reset 		*/
# define ERR_RTDB_CHANGE_DUPLDIR	RTDB_OFFSET+0x07 /* info 		*/
# define ERR_RTDB_BCKP			RTDB_OFFSET+0x08 /* info 		*/
# define ERR_RTDB_DUPL			RTDB_OFFSET+0x09 /* info 		*/
# define ERR_RTDB_WRITE_DISK		RTDB_OFFSET+0x0a /* info 		*/
# define ERR_RTDB_SYNC			RTDB_OFFSET+0x0b /* info		*/
# define ERR_RTDB_MALLOC		RTDB_OFFSET+0x0c /* info		*/
# define ERR_RTDB_BCKPTAB_RECOVERY 	RTDB_OFFSET+0x0d /* info                */
# define ERR_RTDB_DBSYNC_PRIMKEYS 	RTDB_OFFSET+0x0e /* info                */
# define ERR_RTDB_DELETE_BCKPFILE	RTDB_OFFSET+0x0f
# define ERR_RTDB_SYNC_LOG		RTDB_OFFSET+0x10 /* info		*/
# define ERR_RTDB_SYNC_FILE		RTDB_OFFSET+0x11 /* info		*/
# define ERR_RTDB_SYNC_REQ		RTDB_OFFSET+0x12 /* info		*/
# define ERR_RTDB_BCKP_SYNC		RTDB_OFFSET+0x13 /* info		*/



/*************************************/
/*          Error codes for memory.c */
/*************************************/

# define ERR_MEM_RN_CREATE          MEM_OFFSET+0x00
# define ERR_MEM_PT_CREATE          MEM_OFFSET+0x01
# define ERR_IL_CDA_RN_GET          MEM_OFFSET+0x02
# define ERR_IL_CDA_RN_RET          MEM_OFFSET+0x03
# if REGION4
  # define ERR_RN1_ALLOC            MEM_OFFSET+0x04
# endif /* REGION4 */
# define ERR_MEM_MALLOC             MEM_OFFSET+0x05
# define ERR_MEM_STACK_ERR          MEM_OFFSET+0x06+X_FAT	/* reset */
# define ERR_MEM_MALLOC_VXML        MEM_OFFSET+0x07+X_FAT

/***************************************************/
/*          Error codes for L1 DSS1 (U interface)  */
/***************************************************/

#define ERR_L1U_LOSS_SYNCHR	L1U_OFFSET+0x00		/* info */
#define ERR_L1U_LOSS_SIGNAL	L1U_OFFSET+0x01		/* info */
#define ERR_L1U_PSS		L1U_OFFSET+0x02		/* info */
#define ERR_L1U_MAC		L1U_OFFSET+0x03		/* info */
#define ERR_L1U_MFIFO		L1U_OFFSET+0x04		/* info */
#define ERR_L1U_SBV		L1U_OFFSET+0x05		/* info */
#define ERR_L1U_MFAB		L1U_OFFSET+0x06		/* info */
#define ERR_L1U_CODE		L1U_OFFSET+0x07		/* info */
#define ERR_L1U_FRAME_CRC	L1U_OFFSET+0x08		/* info */
#define ERR_L1U_FRAME_RAB	L1U_OFFSET+0x09		/* info */
#define ERR_L1U_FRAME_RDO	L1U_OFFSET+0x0a		/* info */
#define ERR_L1U_TX_QUEUE_FULL 	L1U_OFFSET+0x0b		/* info */
#define ERR_L1U_XDU		L1U_OFFSET+0x0c		/* info */
#define ERR_L1U_RFO		L1U_OFFSET+0x0d		/* info */
#define ERR_L1U_XDOV		L1U_OFFSET+0x0e		/* info */
#define ERR_L1U_BSY		L1U_OFFSET+0x0f		/* info */
#define ERR_L1U_RNA		L1U_OFFSET+0x10		/* info */
#define ERR_L1U_DRV		L1U_OFFSET+0x11		/* info */
#define ERR_L1U_T1		L1U_OFFSET+0x12		/* info */
#define ERR_L1U_T2		L1U_OFFSET+0x13		/* info */
#define ERR_L1U_EI2		L1U_OFFSET+0x14		/* info */
#define ERR_L1U_FJ		L1U_OFFSET+0x15		/* info */
#define ERR_L1U_SPIRIUS		L1U_OFFSET+0x16		/* info */
#define ERR_L1U_NODEVICE	L1U_OFFSET+0x17		/* info */
#define ERR_L1U_INV_TYPE	L1U_OFFSET+0x18		/* info */
#define ERR_L1U_INV_RETURN	L1U_OFFSET+0x19		/* info */


/***************************************************/
/*          Error codes for CAS driver             */
/***************************************************/

/* scanning */
#define ERR_CAS_PID				CAS_OFFSET+0x000	/* pid error */
#define ERR_CAS_CH				CAS_OFFSET+0x001	/* napacen kanal*/
#define ERR_CAS_STATE				CAS_OFFSET+0x002	/* napacen ukaz */
#define ERR_CAS_MFRAME				CAS_OFFSET+0x003	/* izguba multiframa */
#define ERR_CAS_QSEND           		CAS_OFFSET+0x004 	/* wrong qsend */
#define ERR_CAS_MF_LOST_ON_LOCAL_SIDE		CAS_OFFSET+0x005	/* lost of multiframe on local side */
#define ERR_CAS_MF_FOUND_ON_LOCAL_SIDE		CAS_OFFSET+0x006	/* multiframe on local side found */
#define ERR_CAS_MORE_THAN_ONE_MF_ON_LOCAL_SIDE  CAS_OFFSET+0x007	/* more than one multiframes detected on local side */
#define ERR_CAS_MF_LOST_ON_REMOTE_SIDE		CAS_OFFSET+0x008	/* lost of multiframe on remote side */
#define ERR_CAS_MF_FOUND_ON_REMOTE_SIDE 	CAS_OFFSET+0x009	/* multiframe on remote side found */
#define ERR_CAS_RX_BD_ENTRY_WRONG		CAS_OFFSET+0x00a	/* Rx buffer descriptor's entry is configured wrong */
#define ERR_CAS_TX_BD_ENTRY_WRONG		CAS_OFFSET+0x00b	/* Tx buffer descriptor's entry is configured wrong */
#define ERR_CAS_RX_SIRAM_ENTRY_WRONG		CAS_OFFSET+0x00c	/* Rx SI RAM entry is configured wrong */
#define ERR_CAS_TX_SIRAM_ENTRY_WRONG		CAS_OFFSET+0x00d	/* Tx SI RAM entry is configured wrong */
#define ERR_CAS_TX_MULTIFRAME_WRONG		CAS_OFFSET+0x00e	/* transmitting multiframe value does not have valid value */
#define ERR_CAS_PER_INFO_BUFF_NOT_ALOCATED	CAS_OFFSET+0x00f	/* lack of memory for PER_INFO messages */
#define ERR_CAS_PER_INFO_MSG_LOST		CAS_OFFSET+0x010	/* PER_INFO message lost due to lack of memory */

/* initialization */
#define ERR_CAS_INIT_DOUBLE_INIT_ERROR       	CAS_OFFSET+0x100	/* double initiallization of CAS driver */
#define ERR_CAS_INIT_SCC_NUM_ERROR           	CAS_OFFSET+0x101	/* wrong SCC number */
#define ERR_CAS_INIT_TS_NUM_ERROR            	CAS_OFFSET+0x102	/* wrong time slot number */
#define ERR_CAS_INIT_GETMEM_ERROR            	CAS_OFFSET+0x103	/* lack of DPRAM memory */
#define ERR_CAS_INIT_START_SCC_CONTROLER     	CAS_OFFSET+0x104	/* SCC was not started */
#define ERR_CAS_INIT_NO_CAS_TIME_SLOTS	     	CAS_OFFSET+0x105	/* not even one time slot dedicated for */
									/* CAS signalizations */
#define ERR_CAS_INIT_TIME_SLOT		     	CAS_OFFSET+0x106	/* CAS time slot was not initiated properly */
#define ERR_CAS_INIT_CAS_ISR_INSTALL_ERROR   	CAS_OFFSET+0x107	/* CAS Interrupt Service Routine was */
									/* not installed properly */
#define ERR_CAS_INIT_PORT_NUM_ERROR          	CAS_OFFSET+0x108	/* wrong port number */
#define ERR_CAS_INIT_CAS_DRIVER		     	CAS_OFFSET+0x109	/* CAS driver not initiated */
#define	ERR_CAS_INIT_TDMA1_PINS_CONFIG_WRONG	CAS_OFFSET+0x10a	/* MPC860 pins for TDMa1 channel are not configured properly */
#define ERR_CAS_INIT_CAS_MANAGER_CREATE		CAS_OFFSET+0x10b	/* cas_manager() process not started */
#define ERR_CAS_INIT_GET_SHMEM_ERROR           	CAS_OFFSET+0x10c	/* shared memory alocating error */
#define ERR_CAS_INIT_GET_SEM_ERROR           	CAS_OFFSET+0x10d	/* semaphore alocating error */

/* interrupt routine events */
#define ERR_CAS_TXE_ERROR_DETECTED	    	CAS_OFFSET+0x200	/* error on transmitter channel of SCC detected */
#define ERR_CAS_TXE_ERROR_OVERLOAD	     	CAS_OFFSET+0x201	/* too many TXE events */
#define ERR_CAS_BSY_ERROR_DETECTED   	     	CAS_OFFSET+0x202	/* busy condition on receiver channel */
#define ERR_CAS_BSY_ERROR_OVERLOAD   	     	CAS_OFFSET+0x203	/* too many BSY events */
#define ERR_CAS_GLR_ERROR_DETECTED           	CAS_OFFSET+0x204	/* glitch on receive clock detected */
#define ERR_CAS_GLR_ERROR_OVERLOAD           	CAS_OFFSET+0x205	/* too many glitch on receive clock detected */
#define ERR_CAS_GRA_COMMAND_ISSUED           	CAS_OFFSET+0x206	/* GRACEFUL_STOP_TRANSMIT command issued on SCC */
#define ERR_CAS_RX_INT_STARTED               	CAS_OFFSET+0x207	/* Rx interrupt and scanning of CAS channels started */
#define ERR_CAS_RX_INT_STOPPED               	CAS_OFFSET+0x208	/* Rx interrupt and scanning of CAS channels stoped*/
#define ERR_CAS_TX_INT_STARTED               	CAS_OFFSET+0x209	/* Tx interrupt started*/
#define ERR_CAS_TX_INT_STOPPED               	CAS_OFFSET+0x20a	/* Tx interrupt stoped */
	
/* reconfiguration */
#define ERR_CAS_RECONFIG_TS_NUM              	CAS_OFFSET+0x300	/* time slot number is not in range (0-31) or this */
									/* time slot is not configured for CAS signalizations */
#define ERR_CAS_RECONFIG_PORT_NUM            	CAS_OFFSET+0x301	/* wrong port on this time slot; */
#define ERR_CAS_RECONFIG_CHANNEL_VALID       	CAS_OFFSET+0x302	/* time slot already equiped */


/***************************************************/
/*          Error codes for PER driver (all info)  */
/***************************************************/

#define	ERR_PER_X_MSG_L2	PER_OFFSET+0x00	/* UNKNOWN MESSAGE IN L1 QUEUE*/
#define	ERR_PER_Q_REC_E		PER_OFFSET+0x01 /* Q_RECEIVE ERROR MESSAGE    */
#define	ERR_PER_Q_SND_E		PER_OFFSET+0x02 /* Q_SEND ERROR MESSAGE	      */
#define	ERR_PER_MALLOC_ERR	PER_OFFSET+0x03 /* ERROR MEMORY ALLOCATION    */
#define	ERR_PER_SYS_ERR		PER_OFFSET+0x04 /* SYSTEM ERROR		      */
#define	ERR_PER_MF_ERR		PER_OFFSET+0x05 /* MF LOST ERROR	      */


/***************************************************/
/*          Error codes for TAB board  (all info)  */
/***************************************************/

#define ERR_TAB_MAC	TAB_OFFSET+0x00		/* TIMEOUT ERROR ON EPIC      */
#define ERR_TAB_DRV	TAB_OFFSET+0x01		/* SYSTEM ERROR               */
#define ERR_TAB_STAT	TAB_OFFSET+0x02		/* COMBO CONFIGURE ERROR      */
#define ERR_TAB_TAB	TAB_OFFSET+0x03		/* ERROR INIT TAB BOARD       */
#define ERR_SAC_MAC	TAB_OFFSET+0x04		/* TIMEOUT ERROR ON EPIC      */
#define ERR_SAC_DONE	TAB_OFFSET+0x05		/* TIMEOUT ERROR ON SAC       */
#define ERR_SAC_DRV	TAB_OFFSET+0x06		/* SYSTEM ERROR               */

/***************************************************/
/*          Error codes for T1/BIO/CAS driver(CDA) */
/***************************************************/

#define	ERR_BIO_INIT_DOUBLE_INIT_ERROR		BIO_OFFSET+0x001
#define	ERR_BIO_INIT_MRBLR_ERROR		BIO_OFFSET+0x002
#define	ERR_BIO_INIT_WS_NUM_ERROR		BIO_OFFSET+0x003
#define	ERR_BIO_INIT_SCC_NUM_ERROR		BIO_OFFSET+0x004
#define	ERR_BIO_INIT_PORT_NUM_ERROR		BIO_OFFSET+0x005
#define	ERR_BIO_INIT_TS_NUM_ERROR		BIO_OFFSET+0x006
#define	ERR_BIO_INIT_LOGIC_CHAN_NUM_ERROR	BIO_OFFSET+0x007
#define	ERR_BIO_INIT_UNKNOWN_PROTOCOL_ERROR	BIO_OFFSET+0x008
#define	ERR_BIO_INIT_WRONG_STATE_ERROR		BIO_OFFSET+0x009

#define	ERR_BIO_GETMEM_ERROR			BIO_OFFSET+0x100
#define	ERR_BIO_RN_IDENT_ERROR			BIO_OFFSET+0x101
#define	ERR_BIO_Q_IDENT_ERROR			BIO_OFFSET+0x102

#define	ERR_BIO_RAB_OVER_LIMIT			BIO_OFFSET+0x200
#define	ERR_BIO_CRC_OVER_LIMIT			BIO_OFFSET+0x201
#define	ERR_BIO_RDO_ERROR			BIO_OFFSET+0x202
#define	ERR_BIO_NODEVICE_ERROR			BIO_OFFSET+0x203
#define	ERR_BIO_TS_NR_ERROR			BIO_OFFSET+0x204
#define	ERR_BIO_PORT_NR_ERROR			BIO_OFFSET+0x205
#define	ERR_BIO_INVALID_ACCESS_TYPE_ERROR	BIO_OFFSET+0x206
#define	ERR_BIO_FRAME_NOT_COMPLETE_ERROR	BIO_OFFSET+0x207
#define	ERR_BIO_GLOBAL_OVERRUN_ERROR		BIO_OFFSET+0x208
#define	ERR_BIO_GLOBAL_UNDERRUN_ERROR		BIO_OFFSET+0x209
#define	ERR_BIO_INTQUEUE_OVERFLOW_ERROR		BIO_OFFSET+0x20a
#define	ERR_BIO_DUMMY_INTERRUPT_ERROR		BIO_OFFSET+0x20b
#define	ERR_BIO_TXFULL_ERROR			BIO_OFFSET+0x20c
#define	ERR_BIO_RX_CORRUPTED			BIO_OFFSET+0x20d
#define	ERR_BIO_RX_BD_MISMAS			BIO_OFFSET+0x20e
#define	ERR_BIO_RX_HALTED			BIO_OFFSET+0x20f

#define	ERR_BIO_PPP_PORT_ALREADY_OPENED		BIO_OFFSET+0x300
#define	ERR_BIO_PPP_PORT_ALREADY_CLOSED		BIO_OFFSET+0x301
#define	ERR_BIO_PPP_PORT_UNSUPPORTED		BIO_OFFSET+0x302
#define	ERR_BIO_PPP_PORT_OPEN_ERROR		BIO_OFFSET+0x303
#define	ERR_BIO_PPP_PORT_BLOCKED		BIO_OFFSET+0x304
#define	ERR_BIO_PPP_DATA_NOT_SENT		BIO_OFFSET+0x305

#define	ERR_BIO_SIRAM_INIT_WRONG_SCC_NUM	BIO_OFFSET+0x400
#define	ERR_BIO_SIRAM_INIT_WRONG_TS_NUM		BIO_OFFSET+0x401
#define	ERR_BIO_SIRAM_INIT_WRONG_ORDER		BIO_OFFSET+0x402

#define	ERR_BIO_RECONFIG_NOT_ENABLED		BIO_OFFSET+0x500
#define	ERR_BIO_RECONFIG_TS_NUM			BIO_OFFSET+0x501
#define	ERR_BIO_RECONFIG_PORT_NUM		BIO_OFFSET+0x502
#define	ERR_BIO_RECONFIG_WRONG_STATE		BIO_OFFSET+0x503
#define	ERR_BIO_RECONFIG_CHANNEL_VALID		BIO_OFFSET+0x504
#define	ERR_BIO_RECONFIG_UNKNOWN_PROTOCOL	BIO_OFFSET+0x505

#define	ERR_BIO_CAS_INIT_DOUBLE_INIT_ERROR	BIO_OFFSET+0x801
#define	ERR_BIO_CAS_INIT_MRBLR_ERROR		BIO_OFFSET+0x802
#define	ERR_BIO_CAS_INIT_SCC_NUM_ERROR		BIO_OFFSET+0x803
#define	ERR_BIO_CAS_INIT_PORT_NUM_ERROR		BIO_OFFSET+0x804
#define	ERR_BIO_CAS_INIT_TS_NUM_ERROR		BIO_OFFSET+0x805
#define	ERR_BIO_CAS_INIT_WRONG_STATE_ERROR	BIO_OFFSET+0x806

#define	ERR_BIO_CAS_GETMEM_ERROR		BIO_OFFSET+0x900
#define	ERR_BIO_CAS_RN_IDENT_ERROR		BIO_OFFSET+0x901
#define	ERR_BIO_CAS_Q_IDENT_ERROR		BIO_OFFSET+0x902

#define	ERR_BIO_CAS_NODEVICE_ERROR		BIO_OFFSET+0xa00
#define	ERR_BIO_CAS_TX_ERROR			BIO_OFFSET+0xa01
#define	ERR_BIO_CAS_BUSY_ERROR			BIO_OFFSET+0xa02
#define	ERR_BIO_CAS_DUMMY_INTERRUPT_ERROR	BIO_OFFSET+0xa03

#define	ERR_BIO_CAS_RECONFIG_NOT_ENABLED	BIO_OFFSET+0xb00
#define	ERR_BIO_CAS_RECONFIG_TS_NUM		BIO_OFFSET+0xb01
#define	ERR_BIO_CAS_RECONFIG_PORT_NUM		BIO_OFFSET+0xb02
#define	ERR_BIO_CAS_RECONFIG_CHANNEL_VALID	BIO_OFFSET+0xb03

/***************************************************/
/*          Error codes for SO                     */
/***************************************************/

#define ERR_SO_T_CREATE_CDFS                     SO_OFFSET+0x01 /* info */
#define ERR_SO_T_START_CDFS                      SO_OFFSET+0x02 /* info */
#define ERR_SO_T_CREATE_YSMT                     SO_OFFSET+0x03 /* info */
#define ERR_SO_T_START_YSMT                      SO_OFFSET+0x04 /* info */
#define ERR_SO_Q_CREATE_SOCO                     SO_OFFSET+0x05 /* info */
#define ERR_SO_Q_RECEIVE_SOCO                    SO_OFFSET+0x06 /* info */
#define ERR_SO_T_CREATE_SOCO                     SO_OFFSET+0x07 /* info */
#define ERR_SO_T_START_SOCO                      SO_OFFSET+0x08 /* info */
#define ERR_SO_Q_RECEIVE_NOTRECOGNIZED_SOCO      SO_OFFSET+0x09 /* info */
#define ERR_SO_RPC_TIMEOUT_MASTER_OK             SO_OFFSET+0x0a /* info */
#define ERR_SO_DEBUG_JUMPER_SET                  SO_OFFSET+0x0b /* info */
#define ERR_SO_SWITCHOVER_PENDING                SO_OFFSET+0x0c /* info */
#define ERR_SO_RPC_TIMEOUT_SO_MASKED             SO_OFFSET+0x0d /* info */
#define ERR_SO_RPC_TIMEOUT_MASTER_FATAL_ERROR    SO_OFFSET+0x0e /* info */
#define ERR_SO_NET_FAILED_CSB_ONE_TRY            SO_OFFSET+0x0f+X_FAT /* reset */
#define ERR_SO_SWITCHOVER_TYPE                   SO_OFFSET+0x10 /* info */
#define ERR_SO_WRONG_SOSIDESTATE_VALUE		 SO_OFFSET+0x11 /* info */
#define ERR_SO_SZR_LINE_ERROR			 SO_OFFSET+0x12 /* info */
#define ERR_SO_FLAGS_INFO                        SO_OFFSET+0x13 /* info */

/***************************************************/
/*          Error codes for packet communication   */
/*          (all info)                             */
/***************************************************/

#define ERR_PKTP_SYS_ERROR	PKTP_OFFSET+0x00 /*SISTEM CALL ERROR	      */
#define ERR_PKTP_VME_CDA_FULL	PKTP_OFFSET+0x01 /*BUFFER FULL FROM VME TO CDA*/
#define ERR_PKTP_CDA_VME_FULL	PKTP_OFFSET+0x02 /*BUFFER FULL FROM CDA TO VME*/
#define ERR_PKTP_DISPATCH_FAIL	PKTP_OFFSET+0x03 /*ERROR DISPATCHING MESSAGE  */
#define ERR_PKTP_OUT_OF_BOUNDS  PKTP_OFFSET+0x04 /*ERROR OUT OF BOUNDS MESSAGE*/
#define ERR_PKTP_INT            PKTP_OFFSET+0x05 /*RECEIVED PKT IN INTERRUPT  */
#define ERR_PKTP_LOADING_CDA    PKTP_OFFSET+0x06 /*REMOTE CDA NOT LOADED      */
#define ERR_PKTP_Q_SEND_W_PTR   PKTP_OFFSET+0x07 /*ERROR WRITE_PTR OUT OF BOUNDS */
#define ERR_PKTP_Q_SEND_B_PTR   PKTP_OFFSET+0x08 /*ERROR BOTH PTRS OUT OF BOUNDS*/
#define ERR_PKTP_DISP_W_PTR     PKTP_OFFSET+0x09 /*ERROR WRITE_PTR OUT OF BOUNDS */
#define ERR_PKTP_DISP_R_PTR     PKTP_OFFSET+0x0a /*ERROR READ_PTR OUT OF BOUNDS */
#define ERR_PKTP_DISP_B_PTR     PKTP_OFFSET+0x0b /*ERROR BOTH PTRS OUT OF BOUNDS*/
#define ERR_PKTP_Q_SEND_S_PTR   PKTP_OFFSET+0x0c /*ERROR START PTR OUT OF BOUNDS*/
#define ERR_PKTP_Q_SEND_E_PTR   PKTP_OFFSET+0x0d /*ERROR END PTR OUT OF BOUNDS*/
#define ERR_PKTP_DISP_S_PTR     PKTP_OFFSET+0x0e /*ERROR START PTR OUT OF BOUNDS*/
#define ERR_PKTP_DISP_E_PTR     PKTP_OFFSET+0x0f /*ERROR END PTR OUT OF BOUNDS*/
#define ERR_PKTP_UNKNOWN        PKTP_OFFSET+0x10 /*ERROR UNKNOWN ERROR CODE   */


/*****************************************/
/*          Error codes for MTP (SSN7)   */
/*****************************************/
# define ERR_MTP_Q_IDENT	MTP_OFFSET+0x00 /* info */
# define ERR_MTP_Q_SEND		MTP_OFFSET+0x01 /* info */
# define ERR_MTP_SDL_QUEUE_FULL	MTP_OFFSET+0x02 /* info */
# define ERR_MTP_INIT_NO7	MTP_OFFSET+0x03 /* info */
# define ERR_MTP_LNK	        MTP_OFFSET+0x04 /* info */
# define ERR_MTP_DST	        MTP_OFFSET+0x05 /* info */
/* ss7 driver */
#define ERR_SSN7_DRVINIT_WRONGTIMER	MTP_OFFSET+0x04
#define ERR_SSN7_DRVINIT_PQII_NOT_INIT  MTP_OFFSET+0x05
#define ERR_SSN7_DRVINIT_NOMEM_RXBUFF   MTP_OFFSET+0x06
#define ERR_SSN7_DRVINIT_NOMEM_TXFBUFF  MTP_OFFSET+0x07
#define ERR_SSN7_DRVINIT_NOMEM_TXMBUFF  MTP_OFFSET+0x08
#define ERR_SSN7_DRVINIT_NOMEM_RXALLOC  MTP_OFFSET+0x09
#define ERR_SSN7_DRVINIT_TIMERINIT      MTP_OFFSET+0x10
#define ERR_SSN7_CHINIT_WRLNK           MTP_OFFSET+0x11
#define ERR_SSN7_CHINIT_WRCH            MTP_OFFSET+0x12
#define ERR_SSN7_CHINIT_LNKTOBIG        MTP_OFFSET+0x13
#define ERR_SSN7_CHINIT_GETSIROUTE      MTP_OFFSET+0x14
#define ERR_SSN7_CHINIT_MCC_CHINIT_F    MTP_OFFSET+0x15
#define ERR_SSN7_CHSTART_BADLNKNUM      MTP_OFFSET+0x16
#define ERR_SSN7_CHSTART_ACT_F          MTP_OFFSET+0x17
#define ERR_SSN7_CHSTART_CHNOTINIT      MTP_OFFSET+0x18
#define ERR_SSN7_GETL3LNKNO_BADLNKNO    MTP_OFFSET+0x19
#define ERR_SSN7_GETL2LNKNO_BADLNKNO    MTP_OFFSET+0x20
#define ERR_SSN7_RST_TXC_BADLNKNO       MTP_OFFSET+0x21
#define ERR_SSN7_RST_TXC_BADMTD         MTP_OFFSET+0x22
#define ERR_SSN7_RST_TXC_BADFLAG        MTP_OFFSET+0x23
#define ERR_SSN7_STARTRC_BADLNK         MTP_OFFSET+0x24
#define ERR_SSN7_STOPRC_BADLNK          MTP_OFFSET+0x25
#define ERR_SSN7_SSUERM_BADLNK		MTP_OFFSET+0x26
#define ERR_SSN7_STSUERM_BADLNK         MTP_OFFSET+0x27
#define ERR_SSN7_SPROV_BADLNK           MTP_OFFSET+0x28
#define ERR_SSN7_SAERMN_BADLNK          MTP_OFFSET+0x29
#define ERR_SSN7_SAERME_BADLNK          MTP_OFFSET+0x30
#define ERR_SSN7_STAERM_BADLNK          MTP_OFFSET+0x31
#define ERR_SSN7_SDAEDT_BADLNK          MTP_OFFSET+0x32
#define ERR_SSN7_STDAEDT_BADLNK         MTP_OFFSET+0x33
#define ERR_SSN7_SSIOS_BADLNK           MTP_OFFSET+0x34
#define ERR_SSN7_SSIPO_BADLNK           MTP_OFFSET+0x35
#define ERR_SSN7_SSIO_BADLNK            MTP_OFFSET+0x36
#define ERR_SSN7_SSIN_BADLNK            MTP_OFFSET+0x37
#define ERR_SSN7_SSIE_BADLNK            MTP_OFFSET+0x38
#define ERR_SSN7_SFISU_BADLNK           MTP_OFFSET+0x39
#define ERR_SSN7_SMSU_BADLNK            MTP_OFFSET+0x40
#define ERR_SSN7_SDEADR_BADLNK          MTP_OFFSET+0x41
#define ERR_SSN7_RDBSNT_BADLNK          MTP_OFFSET+0x42
#define ERR_SSN7_SUREJECT_BADLNK        MTP_OFFSET+0x43
#define ERR_SSN7_SUACCEPT_BADLNK        MTP_OFFSET+0x44
#define ERR_SSN7_SBUSY_BADLNK           MTP_OFFSET+0x45
#define ERR_SSN7_RETR_BADLNK            MTP_OFFSET+0x46
#define ERR_SSN7_CMSU2L3_BADLNK         MTP_OFFSET+0x47
#define ERR_SSN7_MSGTX_BADLNK           MTP_OFFSET+0x48
#define ERR_SSN7_PUTLSTAT_BADLNK        MTP_OFFSET+0x49
#define ERR_SSN7_GETLSTAT_BADLNK        MTP_OFFSET+0x50
#define ERR_SSN7_GETNOSUERR_BADLNK      MTP_OFFSET+0x51
#define ERR_SSN7_GETMSUDC_BADLNK        MTP_OFFSET+0x52
#define ERR_SSN7_FLBUFF_BADLNK          MTP_OFFSET+0x53
#define ERR_SSN7_UPFSNX_BADLNK          MTP_OFFSET+0x54
#define ERR_SSN7_POOLTSTART_F		MTP_OFFSET+0x55
#define ERR_SSN7_POOLTCR_F		MTP_OFFSET+0x56
#define ERR_SSN7_CDRV_LNKNOTD		MTP_OFFSET+0x57
#define ERR_SSN7_DELCH_BADLNK           MTP_OFFSET+0x58
#define ERR_SSN7_DELCH_CHACT            MTP_OFFSET+0x59
#define ERR_SSN7_DELCH_CHDF             MTP_OFFSET+0x60
#define ERR_SSN7_DELCH_SIRDF            MTP_OFFSET+0x61
#define ERR_SSN7_STOPCH_BADLNK          MTP_OFFSET+0x62
#define ERR_SSN7_STOPCH_CHNOTACT        MTP_OFFSET+0x63
#define ERR_SSN7_STOPCH_CHSTF           MTP_OFFSET+0x64

# define ERR_MTP_SIGINIT_NO7	MTP_OFFSET+0x65 /* info */
# define ERR_MTP_SIG_NO7	MTP_OFFSET+0x66 /* info */
# define ERR_MTP_DRIVER 	MTP_OFFSET+0x67 /* info */
# define ERR_MTP_INITDRIVER 	MTP_OFFSET+0x68 /* info */
# define ERR_MTP_INITCHANNEL 	MTP_OFFSET+0x69 /* info */
# define ERR_MTP_TSTCONFIGSET   MTP_OFFSET+0x70 /* info */
# define ERR_MTP_RECOVERY       MTP_OFFSET+0x71 /* info */
# define ERR_MTP_DSTCONGESTED   MTP_OFFSET+0x72 /* info */


/*****************************************/
/*          Error codes for IL           */
/*****************************************/
#define ERR_IL_UP               IL_OFFSET+0x00  /* info */
#define ERR_IL_PART_LOAD        IL_OFFSET+0x01  /* error/info */
#define ERR_IL_VERIFY           IL_OFFSET+0x02  /* error/info */
#define ERR_IL_VERIFY_ERROR     IL_OFFSET+0x03  /* error */
#define ERR_IL_VERIFY_SKIPED    IL_OFFSET+0x04  /* error */
#define ERR_IL_STRUCT           IL_OFFSET+0x05  /* error */
#define ERR_IL_CHECKSUM         IL_OFFSET+0x06  /* error/info */
#define ERR_IL_PACKET_SWITCH    IL_OFFSET+0x07  /* info */
#define ERR_IL_LOAD_BIN         IL_OFFSET+0x08  /* error */
#define ERR_IL_APP              IL_OFFSET+0x09  /* info */
#define ERR_IL_READ_CFG         IL_OFFSET+0x0a  /* info */
#define ERR_IL_START_PSH        IL_OFFSET+0x0b  /* info */
#define ERR_IL_SHUTDOWN         IL_OFFSET+0x0c  /* info */
#define ERR_IL_WRONG_MODE       IL_OFFSET+0x0d  /* error */
#define ERR_IL_LOG_TASK         IL_OFFSET+0x0e  /* error */
#define ERR_IL_CHANGE           IL_OFFSET+0x0f  /* error */
#define ERR_IL_DUP_IP           IL_OFFSET+0x10  /* error */
#define ERR_IL_TFTP_START       IL_OFFSET+0x11  /* error */

/****************************************/
/*          Error codes for SHM NI      */
/****************************************/
#define ERR_SHM_NO_BUFFERS      SHM_OFFSET+0x00 /* info */

/*******************************************************************/
/*          Error codes for T1/PRA860/CAS860/VOIP860 driver        */
/*******************************************************************/


#define	ERR_PRA860_INIT_DOUBLE_INIT_ERROR	(PRA860_OFFSET+0x001)
#define	ERR_PRA860_INIT_MRBLR_ERROR		(PRA860_OFFSET+0x002)
#define	ERR_PRA860_INIT_WS_NUM_ERROR		(PRA860_OFFSET+0x003)
#define	ERR_PRA860_INIT_SCC_NUM_ERROR		(PRA860_OFFSET+0x004)
#define	ERR_PRA860_INIT_PORT_NUM_ERROR		(PRA860_OFFSET+0x005)
#define	ERR_PRA860_INIT_TS_NUM_ERROR		(PRA860_OFFSET+0x006)
#define	ERR_PRA860_INIT_LOGIC_CHAN_NUM_ERROR 	(PRA860_OFFSET+0x007)
#define	ERR_PRA860_INIT_UNKNOWN_PROTOCOL_ERROR 	(PRA860_OFFSET+0x008)
#define	ERR_PRA860_INIT_WRONG_STATE_ERROR	(PRA860_OFFSET+0x009)
#define	ERR_PRA860_INIT_TDM_NUM_ERROR		(PRA860_OFFSET+0x00a)

#define	ERR_CAS860_INIT_DOUBLE_INIT_ERROR	(CAS860_OFFSET+0x001)
#define	ERR_CAS860_INIT_MRBLR_ERROR		(CAS860_OFFSET+0x002)
#define	ERR_CAS860_INIT_SCC_NUM_ERROR		(CAS860_OFFSET+0x003)
#define	ERR_CAS860_INIT_PORT_NUM_ERROR		(CAS860_OFFSET+0x004)
#define	ERR_CAS860_INIT_TS_NUM_ERROR		(CAS860_OFFSET+0x005)
#define	ERR_CAS860_INIT_WRONG_STATE_ERROR	(CAS860_OFFSET+0x006)
#define	ERR_CAS860_INIT_TDM_NUM_ERROR		(CAS860_OFFSET+0x007)

#define	ERR_PRA860_GETMEM_ERROR			(PRA860_OFFSET+0x100)
#define	ERR_PRA860_RN_IDENT_ERROR		(PRA860_OFFSET+0x101)
#define	ERR_PRA860_Q_IDENT_ERROR		(PRA860_OFFSET+0x102)

#define	ERR_CAS860_GETMEM_ERROR			(CAS860_OFFSET+0x100)
#define	ERR_CAS860_RN_IDENT_ERROR		(CAS860_OFFSET+0x101)
#define	ERR_CAS860_Q_IDENT_ERROR		(CAS860_OFFSET+0x102)

#define	ERR_PRA860_TS_NR_ERROR			(PRA860_OFFSET+0x200)
#define	ERR_PRA860_CRC_ERROR			(PRA860_OFFSET+0x201) /* used as flag, too*/
#define	ERR_PRA860_RDO_ERROR			(PRA860_OFFSET+0x202) /* used as flag, too*/
#define	ERR_PRA860_NODEVICE_ERROR		(PRA860_OFFSET+0x203)
#define	ERR_PRA860_RAB_ERROR			(PRA860_OFFSET+0x204) /* used as flag, too*/
#define	ERR_PRA860_PORT_NR_ERROR		(PRA860_OFFSET+0x205)
#define	ERR_PRA860_INVALID_ACCESS_TYPE_ERROR	(PRA860_OFFSET+0x206)
#define	ERR_PRA860_FRAME_NOT_COMPLETE_ERROR	(PRA860_OFFSET+0x207)
#define	ERR_PRA860_RX_FRAME_TOO_LONG		(PRA860_OFFSET+0x208) /* used as flag, too*/
#define	ERR_PRA860_GLOBAL_UNDERRUN_ERROR	(PRA860_OFFSET+0x209)
#define	ERR_PRA860_INTQUEUE_OVERFLOW_ERROR	(PRA860_OFFSET+0x20a)
#define	ERR_PRA860_DUMMY_INTERRUPT_ERROR	(PRA860_OFFSET+0x20b)
#define	ERR_PRA860_TXFULL_ERROR			(PRA860_OFFSET+0x20c)
#define	ERR_PRA860_GLOBAL_OVERRUN_ERROR		(PRA860_OFFSET+0x20d)
#define	ERR_PRA860_LACK_OF_RX_BD_AND_RX_HALTED	(PRA860_OFFSET+0x20e)
#define	ERR_PRA860_RX_HALTED			(PRA860_OFFSET+0x20f)

#define	ERR_PRA8260_RX_BD_MISMAS		(PRA860_OFFSET+0x220) /* used as flag, too*/
#define	ERR_PRA860_FRAMER_RESET			(PRA860_OFFSET+0x221)
#define	ERR_PRA8260_XX_ERROR			(PRA860_OFFSET+0x222)
#define	ERR_PRA8260_XX_HDLC_ERROR		(PRA860_OFFSET+0x223)
#define	ERR_PRA8260_XX_HDLC_EVENT		(PRA860_OFFSET+0x224)
#define	ERR_PRA8260_XX_INT_ERROR		(PRA860_OFFSET+0x225)
#define	ERR_PRA8260_XX_HDLC_ERROR_BYID		(PRA860_OFFSET+0x226)
#define	ERR_PRA8260_XX_HDLC_EVENT_BYID		(PRA860_OFFSET+0x227)
#define	ERR_PRA8260_XX_HDLC_UNK_ERROR		(PRA860_OFFSET+0x228)
#define	ERR_PRA8260_XX_INT_UNK_ERROR		(PRA860_OFFSET+0x229)
#define	ERR_PRA8260_GETMEM_ERROR		(PRA860_OFFSET+0x22a)
#define	ERR_PRA8260_RN_IDENT_ERROR		(PRA860_OFFSET+0x22b)

#define	ERR_CAS860_NODEVICE_ERROR		(CAS860_OFFSET+0x200)
#define	ERR_CAS860_TX_ERROR			(CAS860_OFFSET+0x201)
#define	ERR_CAS860_BUSY_ERROR			(CAS860_OFFSET+0x202)
#define	ERR_CAS860_DUMMY_INTERRUPT_ERROR	(CAS860_OFFSET+0x203)
#define	ERR_CAS860_RX_INT_STARTED		(CAS860_OFFSET+0x204)
#define	ERR_CAS860_RX_INT_STOPPED		(CAS860_OFFSET+0x205)
#define	ERR_CAS860_TX_INT_STARTED		(CAS860_OFFSET+0x206)
#define	ERR_CAS860_TX_INT_STOPPED		(CAS860_OFFSET+0x207)

#define ERR_CAS860_RECONFIG_NOT_ENABLED         (PRA860_OFFSET+0x210)
#define ERR_CAS860_RECONFIG_TS_NUM              (PRA860_OFFSET+0x211)
#define ERR_CAS860_RECONFIG_PORT_NUM            (PRA860_OFFSET+0x212)
#define ERR_CAS860_RECONFIG_CHANNEL_VALID       (PRA860_OFFSET+0x213)

#define	ERR_PRA860_PPP_PORT_ALREADY_OPENED	(PRA860_OFFSET+0x300)
#define	ERR_PRA860_PPP_PORT_ALREADY_CLOSED	(PRA860_OFFSET+0x301)
#define	ERR_PRA860_PPP_PORT_UNSUPPORTED		(PRA860_OFFSET+0x302)
#define	ERR_PRA860_PPP_PORT_OPEN_ERROR		(PRA860_OFFSET+0x303)
#define	ERR_PRA860_PPP_PORT_BLOCKED		(PRA860_OFFSET+0x304)
#define	ERR_PRA860_PPP_DATA_NOT_SENT		(PRA860_OFFSET+0x305)

#define ERR_PRA860_RECONFIG_NOT_ENABLED         (PRA860_OFFSET+0x310)
#define ERR_PRA860_RECONFIG_TS_NUM              (PRA860_OFFSET+0x311)
#define ERR_PRA860_RECONFIG_PORT_NUM            (PRA860_OFFSET+0x312)
#define ERR_PRA860_RECONFIG_WRONG_STATE         (PRA860_OFFSET+0x313)
#define ERR_PRA860_RECONFIG_CHANNEL_VALID       (PRA860_OFFSET+0x314)
#define ERR_PRA860_RECONFIG_UNKNOWN_PROTOCOL    (PRA860_OFFSET+0x315)

/***************************************************/
/*          Error codes for system protection      */
/***************************************************/

#define ERR_CPROT_SYS_ERR			CPROT_OFFSET+0x00 /* SYSTEM ERROR		*/
#define ERR_CPROT_T_CREATE			CPROT_OFFSET+0x01 /* T_CREATE ERROR		*/
#define ERR_CPROT_Q_CREATE			CPROT_OFFSET+0x02 /* Q_CREATE ERROR		*/
#define ERR_CPROT_T_START			CPROT_OFFSET+0x03 /* T_START ERROR		*/
#define ERR_CPROT_XMSG			 	CPROT_OFFSET+0x04 /* UNKNOWN MESSAGE		*/
#define ERR_CPROT_ALRM_PORT			CPROT_OFFSET+0x05 /* ALARM FOR PORT		*/
#define ERR_CPROT_ALRM_LINK			CPROT_OFFSET+0x06 /* ALARM FOR LINK		*/
#define ERR_CPROT_DB_ADT			CPROT_OFFSET+0x07 /* ERROR READING DB TABLE	*/
#define ERR_CPROT_ALRM_DSP                      CPROT_OFFSET+0x08 /* ALARM FOR DSP              */

#define	ERR_SIRAM_INIT_SCC_NUM_ERROR		(PRA860_OFFSET+0x400)
#define	ERR_SIRAM_INIT_TS_NUM_ERROR		(PRA860_OFFSET+0x401)
#define	ERR_SIRAM_INIT_ORDER_ERROR		(PRA860_OFFSET+0x402)


#define	ERR_VOIP860_INIT_DOUBLE_INIT_ERROR	(VOIP860_OFFSET+0x001)
#define	ERR_VOIP860_INIT_MRBLR_ERROR		(VOIP860_OFFSET+0x002)
#define	ERR_VOIP860_INIT_SCC_NUM_ERROR		(VOIP860_OFFSET+0x003)
#define	ERR_VOIP860_INIT_PORT_NUM_ERROR		(VOIP860_OFFSET+0x004)
#define	ERR_VOIP860_INIT_TS_NUM_ERROR		(VOIP860_OFFSET+0x005)
#define	ERR_VOIP860_INIT_WRONG_STATE_ERROR	(VOIP860_OFFSET+0x006)

#define	ERR_VOIP860_GETMEM_ERROR		(VOIP860_OFFSET+0x100)
#define	ERR_VOIP860_RN_IDENT_ERROR		(VOIP860_OFFSET+0x101)
#define	ERR_VOIP860_Q_IDENT_ERROR		(VOIP860_OFFSET+0x102)

#define	ERR_VOIP860_NODEVICE_ERROR		(VOIP860_OFFSET+0x200)
#define	ERR_VOIP860_TX_ERROR			(VOIP860_OFFSET+0x201)
#define	ERR_VOIP860_BUSY_ERROR			(VOIP860_OFFSET+0x202)
#define	ERR_VOIP860_DUMMY_INTERRUPT_ERROR	(VOIP860_OFFSET+0x203)


/***************************************************/
/*          Error codes for T1/PRA860/CAS860 driver*/
/***************************************************/
#define ERR_ALRP_UNRECOGNIZED_CMD	(ALRP_OFFSET+0x000)
#define ERR_ALRP_CRC			(ALRP_OFFSET+0x001)
#define ERR_ALRP_UNEXPECTED_CMD		(ALRP_OFFSET+0x002)
#define ERR_ALRP_BUZZER_ENB		(ALRP_OFFSET+0x003)
#define ERR_ALRP_BUZZER_DIS		(ALRP_OFFSET+0x004)
#define ERR_ALRP_CONFIRM		(ALRP_OFFSET+0x005)
#define ERR_ALRP_INIT_PORT		(ALRP_OFFSET+0x006)
#define ERR_ALRP_TX_BUF_FULL		(ALRP_OFFSET+0x007)
#define ERR_ALRP_RX_TIMEOUT		(ALRP_OFFSET+0x008)
#define ERR_ALRP_TX_TIMEOUT		(ALRP_OFFSET+0x009)


/***************************************************/
/* Error codes for filesystem transaction control  */
/***************************************************/
#define ERR_XCTRL_RECORDS_EXCEEDED	(XCTRL_OFFSET+0x00)
#define ERR_XCTRL_DISK_CHANGED		(XCTRL_OFFSET+0x01)
#define ERR_XCTRL_RECOVERY_INFO		(XCTRL_OFFSET+0x02)
#define ERR_XCTRL_CRC_ERROR		(XCTRL_OFFSET+0x03)
#define ERR_XCTRL_WRITE_FAIL		(XCTRL_OFFSET+0x04)
#define ERR_XCTRL_READ_FAIL		(XCTRL_OFFSET+0x05)
#define ERR_XCTRL_SRAM_LOCATION		(XCTRL_OFFSET+0x06)
#define ERR_XCTRL_SMF_CREATION		(XCTRL_OFFSET+0x07)
#define ERR_XCTRL_SMF_TIMEOUT		(XCTRL_OFFSET+0x08)
#define ERR_XCTRL_FILE_ACCESS		(XCTRL_OFFSET+0x09)
#define ERR_XCTRL_CANCLED_BY_DELETE	(XCTRL_OFFSET+0x0a)
#define ERR_XCTRL_CANCLED_BY_RESTART	(XCTRL_OFFSET+0x0b)
#define ERR_XCTRL_CANCLED_BY_SUSPEND	(XCTRL_OFFSET+0x0c)
#define ERR_XCTRL_SMF_NESTED		(XCTRL_OFFSET+0x0d)
#define ERR_XCTRL_SMF_TAKEOVER		(XCTRL_OFFSET+0x0e)


/************************************************************/
/* Error codes for Packet InterProcesor Communication -PIPC */
/************************************************************/
#define ERR_PIPC_REPORT			(PIPC_OFFSET+0x00)
#define ERR_PIPC_NO_RESOURCES		(PIPC_OFFSET+0x01)
#define ERR_PIPC_BOARD_DOWN		(PIPC_OFFSET+0x02)
#define ERR_PIPC_CONN_DOWN		(PIPC_OFFSET+0x03)
#define ERR_PIPC_OVERLOAD		(PIPC_OFFSET+0x04)
#define ERR_PIPC_NOT_SENT		(PIPC_OFFSET+0x05)
#define ERR_PIPC_ATM_PULL_BUFFER_FULL   (PIPC_OFFSET+0x06)
#define ERR_PIPC_WARNING		PIPC_OFFSET+0x07+X_WRN


/***************************************************/
/* Error codes for ATM Adaptation Layer      - AAL */
/***************************************************/
#define ERR_AAL_T_CREATE		(AAL_OFFSET+0x000)	/* error */
#define ERR_AAL_T_START			(AAL_OFFSET+0x001)	/* error */
#define ERR_AAL_Q_CREATE		(AAL_OFFSET+0x002)	/* error */
#define ERR_AAL_Q_SEND  		(AAL_OFFSET+0x003)	/* error */
#define ERR_AAL_Q_RECEIVE		(AAL_OFFSET+0x004)	/* error */
#define ERR_AAL_Q_IDENT			(AAL_OFFSET+0x005)	/* error */
#define ERR_AAL_RN_GETSEG               (AAL_OFFSET+0x006)      /* error */
#define ERR_AAL_ATIC_ASSERT		(AAL_OFFSET+0x010)	/* error */
#define ERR_AAL_ATIC_LACKOFMEM		(AAL_OFFSET+0x011)	/* error */
#define ERR_AAL_ATIC_INIT		(AAL_OFFSET+0x012)	/* error */
#define ERR_AAL_AP_INIT			(AAL_OFFSET+0x020)	/* error */
#define ERR_AAL_AAL5_INIT               (AAL_OFFSET+0x030)      /* error */
#define ERR_AAL_AAL5_ACT                (AAL_OFFSET+0x031)      /* error */
#define ERR_AAL_AAL5_ROUTE              (AAL_OFFSET+0x032)      /* error */
#define ERR_AAL_AAL5_GETSTAT            (AAL_OFFSET+0x033)      /* error */
#define ERR_AAL_AAL5_RESETSTAT          (AAL_OFFSET+0x034)      /* error */
#define ERR_AAL_AFM_INIT                (AAL_OFFSET+0x040)      /* error */
#define ERR_AAL_AFM_BIND                (AAL_OFFSET+0x041)      /* error */
#define ERR_AAL_AFM_ADDPVC              (AAL_OFFSET+0x042)      /* error */
#define ERR_AAL_AFM_CREATEFLOW          (AAL_OFFSET+0x043)      /* error */
#define ERR_AAL_ASPEN_BUSY              (AAL_OFFSET+0x044)      /* error */


/***********************/
/* Error codes for ATM */
/***********************/
#define ERR_ATM_SEND_CELL               ATM_OFFSET+0x00        /* error */
#define ERR_ATM_ATMSW_TIMEOUT           ATM_OFFSET+0x01        /* error */
#define ERR_ASPEN_ERR_MAIN              ATM_OFFSET+0x02        /* error */
#define ERR_ASPEN_ERR_ADSL              ATM_OFFSET+0x03        /* error */
#define ERR_ATM_OAM_LB                  ATM_OFFSET+0x04        /* error */
#define ERR_ATM_OAM_CC                  ATM_OFFSET+0x05        /* error */
#define ERR_ATM_ATMSW_CELLBUS_A         ATM_OFFSET+0x06        /* error */
#define ERR_ATM_ATMSW_CELLBUS_B         ATM_OFFSET+0x07        /* error */


/***************************************/
/* Error codes for broadband statistic */ 
/***************************************/
#define ERR_BSTST_STM1_MEAS              BSTST_OFFSET+0x00       /* error */
#define ERR_BSTST_ATMSW_INTR_MEAS        BSTST_OFFSET+0x01       /* error */
#define ERR_BSTST_ATMSW_VPVC_MEAS        BSTST_OFFSET+0x02       /* error */
#define ERR_BSTST_ATMSW_SRV_MEAS         BSTST_OFFSET+0x03       /* error */
#define ERR_BSTST_ATMSW_FIFO_MEAS        BSTST_OFFSET+0x04       /* error */
#define ERR_BSTST_ATMSW_CLEAR_INTR_MEAS  BSTST_OFFSET+0x05       /* error */
#define ERR_BSTST_WRNG_ACTION            BSTST_OFFSET+0x06       /* error */
#define ERR_BSTST_GETDATA                BSTST_OFFSET+0x07       /* error */
#define ERR_BSTST_AAL5_GET_MEAS          BSTST_OFFSET+0x08       /* error */
#define ERR_BSTST_AAL5_GET_DATA          BSTST_OFFSET+0x09       /* error */
#define ERR_BSTST_IMA_GET_DATA           BSTST_OFFSET+0x0A       /* error */
#define ERR_BSTST_IMA_SET_DATA           BSTST_OFFSET+0x0B       /* error */
#define ERR_BSTST_IMA_MEAS               BSTST_OFFSET+0x0C       /* error */
#define ERR_BSTST_MEAS_OVLD              BSTST_OFFSET+0x0D       /* error */
#define ERR_BSTST_ADD_OVLD               BSTST_OFFSET+0x0E       /* error */
#define ERR_BSTST_ETH_SET_DATA           BSTST_OFFSET+0x0F       /* error */
#define ERR_BSTST_ETHINTF_MEAS           BSTST_OFFSET+0x10       /* error */
#define ERR_BSTST_ETHLINE_MEAS           BSTST_OFFSET+0x11       /* error */
#define ERR_BSTST_AAL5_SET_DATA          BSTST_OFFSET+0x12       /* error */
#define ERR_BSTST_AAL5_MEAS              BSTST_OFFSET+0x13       /* error */
#define ERR_BSTST_ATMSW_MEAS             BSTST_OFFSET+0x14       /* error */
#define ERR_BSTST_ATMSW_SET_DATA         BSTST_OFFSET+0x15       /* error */
#define ERR_BSTST_ETH                    BSTST_OFFSET+0x16       /* error */
#define ERR_BSTST_MK_FILE                BSTST_OFFSET+0x17       /* error */
#define ERR_BSTST_CLI                    BSTST_OFFSET+0x18       /* error */
#define ERR_BSTST_STM_SET_DATA           BSTST_OFFSET+0x19       /* error */
#define ERR_BSTST_ATM25_SET_DATA         BSTST_OFFSET+0x1A       /* error */
#define ERR_BSTST_ATM25_MEAS             BSTST_OFFSET+0x1B       /* error */
#define ERR_BSTST_START_ERR              BSTST_OFFSET+0x1C       /* error */
#define ERR_BSTST_INFO                   BSTST_OFFSET+0x1D       /* info  */


/***************************************************/
/* Error codes for VOIP - H323                     */
/***************************************************/
#define ERR_VOIP_RN_GETSEG               VOIP_OFFSET+0x00
#define ERR_VOIP_Q_SEND                  VOIP_OFFSET+0x01
#define ERR_VOIP_SEND                    VOIP_OFFSET+0x02
#define ERR_VOIP_RN_RETSEG               VOIP_OFFSET+0x03
#define ERR_VOIP_INTER_CONNECT           VOIP_OFFSET+0x04

/***************************************************/
/* Error codes for CLI                             */
/***************************************************/
#define ERR_CLI_ERROR                    CLI_OFFSET+0x00
#define ERR_CLI_INFO                     CLI_OFFSET+0x01+X_INF


/***************************************/
/* Error codes for InitMng             */ 
/***************************************/
#define ERR_INITMNG_RESET_MAIN_BOARD_REQUEST         INITMNG_OFFSET+0x00         /* Exec reset main board request from InitMng */
#define ERR_INITMNG_RESET_BOARD_REQUEST              INITMNG_OFFSET+0x01         /* Exec reset board request from InitMng */
#define ERR_INITMNG_DB_BAD_BOARD_DATA                INITMNG_OFFSET+0x02         /* Bad DB data for given board */
#define ERR_INITMNG_DB_BAD_PORT_DATA                 INITMNG_OFFSET+0x03         /* Bad DB data for given port */
#define ERR_INITMNG_QUDI_NOT_SYS_STATE_OPERATIONAL   INITMNG_OFFSET+0x04         /* Current QUDI not SYS_STATE_OPERATIONAL */
#define ERR_INITMNG_DB_BAD_IMA_GRP_PROFILE_DATA      INITMNG_OFFSET+0x05         /* Bad DB data for given IMA group */
#define ERR_INITMNG_DB_BAD_IMA_PORT_DATA             INITMNG_OFFSET+0x06         /* Bad DB data for IMA */
#define ERR_INITMNG_DB_BAD_IMA_GROUPS_DATA           INITMNG_OFFSET+0x07         /* Bad DB data for IMA groups */
#define ERR_INITMNG_DB_BAD_IMA_GROUP_MEMBERS_DATA    INITMNG_OFFSET+0x08         /* Bad DB data for IMA group members */
#define ERR_INITMNG_IMA_COMP_EQUIP_AFFECT            INITMNG_OFFSET+0x09         /* Changing equipment of IMA component will affect after reseting board */

/**********************************************************/
/* Error codes for digital switch connections             */ 
/**********************************************************/
#define ERR_SW_TDM                                   SW_OFFSET+0x00              /* Error on TDM switch access */
#define ERR_SW_SOFT                                  SW_OFFSET+0x01              /* Error manipulating SW copy of switch  */

/**********************************************************/
/* Error codes for AT modules                             */ 
/**********************************************************/
#define ERR_AT_INFO                                  AT_OFFSET+0x00

/**********************************************************/
/* Error codes for windview                               */ 
/**********************************************************/
#define ERR_WV_START                                 WV_OFFSET+0x00              /* start windview  */
#define ERR_WV_END                                   WV_OFFSET+0x01              /* end of windview */
#define ERR_WV_FILE                                  WV_OFFSET+0x02              /* name of wv file  */


/**********************************************************/
/* Error codes for mdim                                   */
/**********************************************************/
#define ERR_CORE_DOWN                                MDIM_OFFSET+0x01              /* core failure - info */
#define ERR_SA_DOWN                                  MDIM_OFFSET+0x02              /* sa failure - info */
#define ERR_DSP_DOWN                                 MDIM_OFFSET+0x03              /* dsp failure - info */
#define ERR_DIM_FATAL                                MDIM_OFFSET+0x04              /* dim failure - reset */
#define ERR_SA_RECOVERY_STOPPED                      MDIM_OFFSET+0x05              /* sa failure - info */
#define ERR_SA_INIT_DOWN                             MDIM_OFFSET+0x06              /* sa failure - info */

#define ERR_MDIM_CORE_DOWN                           MDIM_OFFSET+0x07            /* core failure - info */
#define ERR_MDIM_DSP_DOWN                            MDIM_OFFSET+0x08            /* dsp failure - info */
#define ERR_MDIM_DIM_FATAL                           MDIM_OFFSET+0x09            /* dim failure - reset */
#define ERR_MDIM_PIPC_DOWN                           MDIM_OFFSET+0x10            /* pipc error - info */
#define ERR_MDIM_TELOGY                              MDIM_OFFSET+0x11            /* telogy error - info */
#define ERR_MDIM_WRONG_SIGNAL                        MDIM_OFFSET+0x12            /* undefined signal - info */
#define ERR_MDIM_CORE_UP                             MDIM_OFFSET+0x13            /* core up - info */
#define ERR_MDIM_CORE_LOAD                           MDIM_OFFSET+0x14            /* core load - info */
#define ERR_MDIM_CFGREQ_ERR                          MDIM_OFFSET+0x15            /* core load - info */
#define ERR_MDIM_SIGNAL_OK                           MDIM_OFFSET+0x16            /* no signal - properly wrong IP */
#define ERR_MDIM_NO_SIGNAL                           MDIM_OFFSET+0x17            /* sig_mgm_dim_startupconf received */
#define ERR_MDIM_WDT_START                           MDIM_OFFSET+0x18            /* sig_start_timer send */
#define ERR_MDIM_SEND_RESET                          MDIM_OFFSET+0x19            /* sig_dim_reset send to dim, because mgm not responding */
#define ERR_MDIM_NW_OPEN                             MDIM_OFFSET+0x1a+X_FAT	     /* reset */


/**********************************************************/
/* Error codes for RTCP                                   */
/**********************************************************/
#define ERR_RTCP_INIT                          RTCP_OFFSET+0x00            /* init rtcp module */
#define ERR_RTCP_OPEN                          RTCP_OFFSET+0x01            /* open rtcp connection */
#define ERR_RTCP_CLOSE                         RTCP_OFFSET+0x02            /* close rtcp connection */
#define ERR_RTCP_RECV_SEND                     RTCP_OFFSET+0x03            /* rtcp receive - send data */
#define ERR_RTCP_PCU	                       RTCP_OFFSET+0x04            /* h323task on pcu not created - can't get IP */

/**********************************************************/
/* Error codes for H323                                   */ 
/**********************************************************/
#define ERR_H323_PIPE_CREATE			      H323_OFFSET+0x00		   /* H323 pipe cerate error */
#define ERR_H323_PIPE_TIMEOUT			      H323_OFFSET+0x01		   /* H323 pipe timeout */
#define ERR_H323_PIPE_GW_WRITE			      H323_OFFSET+0x02		   /* H323 gateway pipe write error */
#define ERR_H323_PIPE_GW_READ			      H323_OFFSET+0x03		   /* H323 gateway pipe read error */
#define ERR_H323_PIPE_WRITE			      H323_OFFSET+0x04		   /* H323 stack pipe write error */
#define ERR_H323_PIPE_READ			      H323_OFFSET+0x05		   /* H323 stack pipe read error */
#define ERR_H323_PIPE_MALLOC			      H323_OFFSET+0x06		   /* H323 voip_send malloc error */
#define ERR_H323_PIPE_FLAG			      H323_OFFSET+0x07		   /* H323 flag not as expected */
#define ERR_H323_VOIP_MASK			      H323_OFFSET+0x08		   /* H323 voip_send mask not valid*/
#define ERR_H323_INIT				      H323_OFFSET+0x09		   /* H323 init error*/
#define ERR_H323_PIPE_OPEN			      H323_OFFSET+0x0A		   /* H323 pipe open error*/
#define ERR_H323_PIPE_REG			      H323_OFFSET+0x0B		   /* H323 pipe event registered error */


/**********************************************************/
/* Error codes for PPP (MsgStat)                          */ 
/**********************************************************/
#define ERR_PPP_DB				      PPP_OFFSET+0x00		   /* PPP ppp_connection table error */
#define ERR_PPP_CHANNEL 			      PPP_OFFSET+0x01		   /* PPP no physical channel */
#define ERR_PPP_PROFILE				      PPP_OFFSET+0x02		   /* PPP profile error */
#define ERR_PPP_STACK				      PPP_OFFSET+0x03		   /* PPP stack was not added */
#define ERR_PPP_CONNECTION			      PPP_OFFSET+0x04		   /* PPP connection not opened */
#define ERR_PPP_MEMORY				      PPP_OFFSET+0x05		   /* PPP ran out of memory */
#define ERR_PPP_SEMAPHORE			      PPP_OFFSET+0x06		   /* PPP could not get semaphore */
#define ERR_PPP_CLI				      PPP_OFFSET+0x07		   /* PPP CLI error */
#define ERR_PPP_CONTROL				      PPP_OFFSET+0x08		   /* PPP control layer error */
#define ERR_PPP_DATA				      PPP_OFFSET+0x09		   /* PPP data plane error */
#define ERR_PPP_PFW				      PPP_OFFSET+0x0A		   /* PPP protocol framework */
#define ERR_PPP_STATE				      PPP_OFFSET+0x0B		   /* PPP state machine error */


/**********************************************************/
/* Error codes for a bridge module                        */ 
/**********************************************************/
#define ERR_BRIDGE_ERROR			      BRIDGE_OFFSET+0x00	   /* The functionality is not realized yet */
#define ERR_BRIDGE_NOT_REALIZED			      BRIDGE_OFFSET+0x01	   /* */
#define ERR_BRIDGE_CAN_NOT_INITIALIZE		      BRIDGE_OFFSET+0x02	   /* */
#define ERR_BRIDGE_ALREADY_INITIALIZED		      BRIDGE_OFFSET+0x03	   /* */
#define ERR_BRIDGE_TOO_MANY_PORTS		      BRIDGE_OFFSET+0x04	   /* */
#define ERR_BRIDGE_CANNOT_MODIFY_PORTS		      BRIDGE_OFFSET+0x05	   /* */
#define ERR_BRIDGE_CANNOT_RECONFIGURE_PORT	      BRIDGE_OFFSET+0x06	   /* */
#define ERR_BRIDGE_INCORRECT_VID		      BRIDGE_OFFSET+0x07	   /*vid is incorrect*/
#define ERR_BRIDGE_MAX_VLAN_REACHED		      BRIDGE_OFFSET+0x08	   /*you have reached the maximum allowed number of VLANs in system*/
#define ERR_BRIDGE_VLAN_NO_RULE			      BRIDGE_OFFSET+0x09	   /*You try to do something with vlan (in)(e)gress rule which is not present*/
#define ERR_BRIDGE_VLAN_RULE_ALREADY_ADDED	      BRIDGE_OFFSET+0x0a	   /*You try to add vlan (in)(e)gress rule which is already added*/
#define ERR_BRIDGE_INVALID_PHYSICAL_PORT_NUMBER	      BRIDGE_OFFSET+0x0b	   /* */
#define ERR_BRIDGE_CANNOT_CONFIGURE	     	      BRIDGE_OFFSET+0x0c	   /* */
#define ERR_BRIDGE_CANNOT_CHANGE_PORT_STATE           BRIDGE_OFFSET+0x0d	   /* */
#define ERR_BRIDGE_CANNOT_CONNECT_PORT	              BRIDGE_OFFSET+0x0e	   /* */
#define ERR_BRIDGE_INTERNAL_PORT_DOES_NOT_SUPPORT_STP BRIDGE_OFFSET+0x0f	   /* */
#define ERR_BRIDGE_CANNOT_DETECT_MAC_ADDRESS_OF_PORT  BRIDGE_OFFSET+0x10	   /* */
#define ERR_BRIDGE_CANNOT_ASSIGN_BRIDGE_MAC_ADDRESS   BRIDGE_OFFSET+0x11	   /* */
#define ERR_BRIDGE_UNKOWN_PORT_TYPE		      BRIDGE_OFFSET+0x12	   /* */
#define ERR_BRIDGE_STATISTICS_IS_NOT_INCLUDED	      BRIDGE_OFFSET+0x13	   /* */
#define ERR_BRIDGE_TOO_MANY_STATISTICS		      BRIDGE_OFFSET+0x14	   /* */
#define ERR_BRIDGE_LOW_MEMORY			      BRIDGE_OFFSET+0x15	   /* */
#define ERR_BRIDGE_BUSY				      BRIDGE_OFFSET+0x16	   /* */
#define ERR_BRIDGE_CANNOT_DELETE_PORT		      BRIDGE_OFFSET+0x17	   /* */
#define ERR_BRIDGE_ID_IS_NULL			      BRIDGE_OFFSET+0x18	   /* */
#define ERR_BRIDGE_PORT_ID_IS_NULL		      BRIDGE_OFFSET+0x19	   /* */

/**********************************************************/
/* Error codes for ACS client                             */
/**********************************************************/
#define ERR_ACS_ERROR                                 ACS_OFFSET+0x00              /* Error generally */
#define ERR_ACS_CHANGED                               ACS_OFFSET+0x01              /* Notifications */
#define ERR_ACS_NOT_REALIZED                          ACS_OFFSET+0x02              /* The functionality is not realized yet */
#define ERR_ACS_CAN_NOT_INITIALIZE                    ACS_OFFSET+0x03              /* Initialization error */
#define ERR_ACS_ALREADY_INITIALIZED                   ACS_OFFSET+0x04              /* ACS is already initialized */
#define ERR_ACS_DISK                                  ACS_OFFSET+0x05              /* Disk problems or file not found on disk */
#define ERR_ACS_FTP_ERROR                             ACS_OFFSET+0x06              /* FTP problems in download function */
#define ERR_ACS_REBOOT_SYSTEM                         ACS_OFFSET+0x07              /* ACS client reboots the system */

/**********************************************************/
/* Error codes for Level7 module                          */ 
/**********************************************************/
#define ERR_LVL7_MSG				      LVL7_OFFSET+0x00

/**********************************************************/
/* Error codes for ISS module                             */ 
/**********************************************************/
#define ERR_ISS_MSG				      ISS_OFFSET+0x00

/**********************************************************/
/* Error codes for Vinetic driver                         */ 
/**********************************************************/
#define ERR_VINETIC_ERROR                                   VINETIC_OFFSET+0x00        /* The functionality is not realized yet */
#define ERR_VINETIC_DEVICE_NOT_OPENED                       VINETIC_OFFSET+0x01        /* Vinetic device not created */
#define ERR_VINETIC_CHANNEL_NOT_OPENED                      VINETIC_OFFSET+0x02        /* Vinetic channel not created */
#define ERR_VINETIC_CHANNEL_NOT_INITIALIZE                  VINETIC_OFFSET+0x03        /* Vinetic channel not initialize */
#define ERR_VINETIC_SHOW_ERROR                              VINETIC_OFFSET+0x04        /* Show last error caused on Vinetic driver */
#define ERR_VINETIC_PCM_CANNOT_BE_CONFIG                    VINETIC_OFFSET+0x05        /* PCM cannot be config and activate */
#define ERR_VINETIC_SLIC_CANNOT_BE_SELECTED                 VINETIC_OFFSET+0x06        /* SLIC type selection is not created */
#define ERR_VINETIC_OPERATING_MODE_CANNOT_BE_SELECTED       VINETIC_OFFSET+0x07        /* Operating mode of Vinetic chip set is not selected */
#define ERR_VINETIC_EXCEPTION_IS_NOT_SELECTED               VINETIC_OFFSET+0x08        /* Unmasking phone exceptions is not created */
#define ERR_VINETIC_CRAM_COEFFICIENT_LOAD_FAILED            VINETIC_OFFSET+0x09        /* CRAM coefficients loading failed */
#define ERR_VINETIC_CURRENT_LIMITATION_WAS_NOT_ACTIVATED    VINETIC_OFFSET+0x0a        /* Current limitation was not activated */
#define ERR_VINETIC_FATAL    VINETIC_OFFSET+0x0b+X_FAT																 /* Vinetic driver task isn't started */


/**********************************************************/
/* Error codes for Vinetic interface API                  */ 
/**********************************************************/
#define ERR_AALN_ERROR			            AALN_OFFSET+0x00	   /* The functionality is not realized yet */
#define ERR_AALN_MSG_QUEUE_NOT_CREATED			            AALN_OFFSET+0x01	   /* Queue not created */
#define ERR_AALN_TIMER_MSG_QUEUE_NOT_CREATED			            AALN_OFFSET+0x02	   /* Queue for timer handling not created */
#define ERR_AALN_WD_TIMER_NOT_CREATED			            AALN_OFFSET+0x03	   /* Watchdog timer initiailization FAILED */
#define ERR_AALN_RING_CONFIGURATION_IS_NOT_INITIALIZE			            AALN_OFFSET+0x04	   /* Ringing configuration is not set */
#define ERR_AALN_RING_CADENCE_IS_NOT_INITIALIZE			            AALN_OFFSET+0x05	   /* Ringing cadence is not set */
#define ERR_AALN_EVENT_RECEIVE_FAILED			            AALN_OFFSET+0x06	   /* Event receive error */
#define ERR_AALN_EVENT_TIMER_RECEIVE_FAILED			            AALN_OFFSET+0x07	   /* Timer event receive error */
#define ERR_AALN_PORT_BLOCKED			            AALN_OFFSET+0x08	   /* Analog port blocked */
#define ERR_AALN_PORT_RESET			            AALN_OFFSET+0x09	   /* Analog port reset */   

/**********************************************************/
/* Error codes for application                            */ 
/**********************************************************/
#define ERR_MGCP_ERROR			            MGCP_OFFSET+0x00	   /* The functionality is not realized yet */
#define ERR_MGCP_NOT_STARTED			    MGCP_OFFSET+0x01	   /* Mgcp Server not started! */
#define ERR_MGCP_NO_HOSTNAME			    MGCP_OFFSET+0x02	   /* Mgcp has no host name! */
#define ERR_MGCP_NO_DOMAINNAME			    MGCP_OFFSET+0x03	   /* Mgcp has no domain name! */
#define ERR_MGCP_SERVER_FAILURE			    MGCP_OFFSET+0x04	   /* Mgcp server failure! */
#define ERR_MGCP_CONNECTION_FAILURE			    MGCP_OFFSET+0x05	   /* Mgcp connection failure! */
#define ERR_MGCP_NO_ENDPOINTS			    MGCP_OFFSET+0x06	   /* Mgcp has no endpoints! */
#define ERR_MGCP_ENDPOINT_DISCONNECTED			    MGCP_OFFSET+0x07	   /* Endpoint disconnected! No response! */

/**********************************************************/
/* Error codes for BCM eth switch                         */
/**********************************************************/
#define ERR_ETHSW_ERROR				    ETHSW_OFFSET+0x00
#define ERR_ETHSW_VLAN_CREATE			    ETHSW_OFFSET+0x01
#define ERR_ETHSW_OK				    ETHSW_OFFSET+0x02

/**********************************************************/
/* Error codes for SSH server                            */
/**********************************************************/
#define ERR_SSH_ERROR			            SSH_OFFSET+0x00	   	   /* Error SSH messages */
#define ERR_SSH_INFO			            SSH_OFFSET+0x01+X_INF	   /* Logging messages */

/**********************************************************/
/* Error codes for application MEGACO                     */ 
/**********************************************************/
#define ERR_MEG_ERROR                   MEG_OFFSET+0x00	   /* Megaco Error */
#define ERR_MEG_NOT_STARTED             MEG_OFFSET+0x01	   /* Megaco Server not started! */
#define ERR_MEG_NO_HOSTNAME             MEG_OFFSET+0x02	   /* Megaco has no host name! */
#define ERR_MEG_NO_DOMAINNAME           MEG_OFFSET+0x03	   /* Megaco has no domain name! */
#define ERR_MEG_SERVER_FAILURE          MEG_OFFSET+0x04	   /* Megaco server failure! */
#define ERR_MEG_CONNECTION_FAILURE      MEG_OFFSET+0x05	   /* Megaco connection failure! */
#define ERR_MEG_NO_ENDPOINTS            MEG_OFFSET+0x06	   /* Megaco has no endpoints! */
#define ERR_MEG_ENDPOINT_DISCONNECTED   MEG_OFFSET+0x07	   /* Megaco endpoint disconnected */
#define ERR_MEG_NO_TERMINATION          MEG_OFFSET+0x08	   /* Megaco no termination */

/**********************************************************/
/* Error codes for PQII/PQIII CPM                         */ 
/**********************************************************/
#define ERR_CPM_HALT                   CPM_OFFSET+0x00	   /* CPM Halts */

/**********************************************************/
/* Error codes for IPMC firmware update aplication        */
/**********************************************************/
#define ERR_IPMC_NO_MEMORY              IPMC_OFFSET+0x00    /* Can't allocate enough memory for update functionality */
#define ERR_IPMC_OPEN_FILE              IPMC_OFFSET+0x01    /* Can't open IPMC update file */
#define ERR_IPMC_PARSING_FILE           IPMC_OFFSET+0x02    /* Error parsing update file */
#define ERR_IPMC_BOOT_CONNECT           IPMC_OFFSET+0x03    /* Error connect IPMC boot mode */
#define ERR_IPMC_BOOT_DISCONNECT        IPMC_OFFSET+0x04    /* Error disconect IPMC from boot mode */
#define ERR_IPMC_FLASH_WRITE            IPMC_OFFSET+0x05    /* Write to IPMC flash failed */
#define ERR_IPMC_NVRAM_WRITE            IPMC_OFFSET+0x06    /* Write to IPMC EEPROM failed */
#define ERR_IPMC_UPDATE_FAILD           IPMC_OFFSET+0x07    /* IPMC firmware update failed */

/**********************************************************/
/* Error codes for DHCP Client                            */
/**********************************************************/
#define ERR_DHCPC_SERVER_NOT_ACCESSIBLE DHCPC_OFFSET+0x00    /* DHCP Server is not responding */
#define ERR_DHCPC_SERVER_IP             DHCPC_OFFSET+0x01    /* DHCP Server is not responding */

/**********************************************************/
/* Error codes for Multi-Link Network Conectivity         */
/**********************************************************/
#define ERR_MLNC_INIT_ERR               MLNC_OFFSET+0x00    /* Just for statistics */
#define ERR_MLNC_INIT_STAT              MLNC_OFFSET+0x01    /* Just for statistics */
#define ERR_MLNC_STAT                   MLNC_OFFSET+0x02    /* Just for statistics */
#define ERR_MLNC_DATA_ERR               MLNC_OFFSET+0x03    /* Just for statistics */
#define ERR_MLNC_ERR                    MLNC_OFFSET+0x04    /* Just for statistics */

/**********************************************************/
/* Error codes for DGM                                    */
/**********************************************************/
#define ERR_DGM_ERROR			DGM_OFFSET+0x00    /* DGM error */
#define ERR_DGM_DLOPEN_ERR		DGM_OFFSET+0x01    /* DGM - dlopen error */
#define ERR_DGM_DLSYM_ERR		DGM_OFFSET+0x02    /* DGM - dlsym error */
#define ERR_DGM_FORK			DGM_OFFSET+0x03    /* DGM - fork failed */
#define ERR_DGM_N_CLNTS			DGM_OFFSET+0x04    /* DGM - fork failed */
#define ERR_DGM_CLIENTS			DGM_OFFSET+0x05+X_INF    /* DGM - fork failed */


/**********************************************************/
/* Error codes for FLASH BBM                              */ 
/**********************************************************/
#define ERR_FLASH_BBM_ERROR                                 FLASH_BBM_OFFSET+0x00    /* Flash spare sector is used */

/**********************************************************/
/* Error codes for LIDIA                                  */ 
/**********************************************************/
#define ERR_LIDIA_ERROR			LIDIA_OFFSET+0x00
#define ERR_LIDIA_INIT			LIDIA_OFFSET+0x01
#define ERR_LIDIA_INIT_INF		LIDIA_OFFSET+0x02+X_INF
#define ERR_LIDIA_WORK			LIDIA_OFFSET+0x03
#define ERR_LIDIA_WORK_INF		LIDIA_OFFSET+0x04+X_INF
#define ERR_LIDIA_PHY_STATE		LIDIA_OFFSET+0x05+X_INF
#define ERR_LIDIA_PHY_CRC_ERR		LIDIA_OFFSET+0x06
#define ERR_LIDIA_PHY_BUSY_ERR		LIDIA_OFFSET+0x07
#define ERR_LIDIA_PHY_OVERRUN		LIDIA_OFFSET+0x08
#define ERR_LIDIA_PHY_DROPPED		LIDIA_OFFSET+0x09
#define ERR_LIDIA_PHY_COLLISION		LIDIA_OFFSET+0x0a
#define ERR_LIDIA_PHY_LATE_COLL		LIDIA_OFFSET+0x0b
#define ERR_LIDIA_PHY_UNDERRUN		LIDIA_OFFSET+0x0c
#define ERR_LIDIA_PHY_PER		LIDIA_OFFSET+0x0d

/**********************************************************/
/* Error codes for ODBC connectivity                      */
/**********************************************************/
#define ERR_ODBC_CONNECT                ODBC_OFFSET+0x00
#define ERR_ODBC_FUNC                   ODBC_OFFSET+0x01
#define ERR_ODBC_SIPC                   ODBC_OFFSET+0x02

/**********************************************************/
/* Error codes for ZARLINK diagnostics                    */
/**********************************************************/
#define ERR_ZL_DIAG                     ZL_DIAG_OFFSET+0x00 /* Error in Zarlink diagnostics application */
#define ERR_ZL_DIAG_SEM_ALLOC           ZL_DIAG_OFFSET+0x01 /* Error allocating semaphore */
#define ERR_ZL_DIAG_SEM_INIT            ZL_DIAG_OFFSET+0x02 /* Error initializing semaphore */
#define ERR_ZL_DIAG_SEM_TAKE            ZL_DIAG_OFFSET+0x03 /* Error taking semaphore */
#define ERR_ZL_DIAG_SEM_GIVE            ZL_DIAG_OFFSET+0x04 /* Error giving semaphore */
#define ERR_ZL_DIAG_DEV_OPEN            ZL_DIAG_OFFSET+0x05 /* Error opening device */
#define ERR_ZL_DIAG_DEV_CLOSE           ZL_DIAG_OFFSET+0x06 /* Error closing device */
#define ERR_ZL_DIAG_ALR_RET             ZL_DIAG_OFFSET+0x07 /* Alarm retreating failded */
#define ERR_ZL_DIAG_ALR_REP             ZL_DIAG_OFFSET+0x08 /* Alarm reporting failed */
#define ERR_ZL_DIAG_READ_STAT           ZL_DIAG_OFFSET+0x09 /* Statistic counters reading failed */
#define ERR_ZL_DIAG_DEL_STAT            ZL_DIAG_OFFSET+0x0a /* Statistic counters deleting failed */
#define ERR_ZL_DIAG_APP_ERR             ZL_DIAG_OFFSET+0x0b /* Diagnostic application executing error */
#define ERR_ZL_DIAG_IOCTL               ZL_DIAG_OFFSET+0x0c /* Ioctl call failed */
#define ERR_ZL_DIAG_READ_MSG            ZL_DIAG_OFFSET+0x0d /* Interrupt message reading failed */
#define ERR_ZL_DIAG_MMAP                ZL_DIAG_OFFSET+0x0e /* Device registers memory map failed */

/***********************************************************/
/* Error codes for HW initialization                       */
/***********************************************************/
#define ERR_HW_INIT_MSGGET              HW_INIT_OFFSET+0x01 /* Error creating message queue */
#define ERR_HW_INIT_MSGRCV              HW_INIT_OFFSET+0x02 /* Error receiving message */
#define ERR_HW_INIT_MSGSND              HW_INIT_OFFSET+0x03 /* Error sending message */
#define ERR_HW_INIT_MSGCTL              HW_INIT_OFFSET+0x04 /* Error removing message queue */
#define ERR_HW_INIT_PIPC                HW_INIT_OFFSET+0x05 /* Error in PIPC communication */
#define ERR_HW_INIT_SHM_GET             HW_INIT_OFFSET+0x06 /* Error in creating shared memory */
#define ERR_HW_INIT_SHM_CTL             HW_INIT_OFFSET+0x07 /* Error in managing shared memory */

/**********************************************************/
/* Error codes for Mac Source Guard                       */ 
/**********************************************************/
#define ERR_MACSG_SEMAPHORE_ID_IS_NULL		      MACSG_OFFSET+0x00	   /* Semaphore ID is NULL! */
#define ERR_MACSG_SPAWN_ERROR		      	      MACSG_OFFSET+0x01	   /* Can't spawn mac source guard task! */
#define ERR_MACSG_BRIDGE_ID_IS_NULL	      	      MACSG_OFFSET+0x02	   /* Bridge ID is NULL! */
#define ERR_MACSG_PORT_IS_NULL			      MACSG_OFFSET+0x03	   /* Port is NULL */
#define ERR_MACSG_ERROR_DATA_FOR_PORT	      	      MACSG_OFFSET+0x04	   /* Error in data for port! */
#define ERR_MACSG_NOT_FIND_TYPE_OF_PORT	      	      MACSG_OFFSET+0x05	   /* Didn`t find type of port! */
#define ERR_MACSG_ENABLED			      MACSG_OFFSET+0x06    /* MAC SG started */
#define ERR_MACSG_DISABLED			      MACSG_OFFSET+0x07    /* MAC SG administated DISABLED*/

/**********************************************************/
/* Error codes for SNMP agent                             */ 
/**********************************************************/
#define ERR_SNMP_GENERIC                        SNMP_OFFSET+0x00
#define ERR_SNMP_ENTRY_NOT_FOUND                SNMP_OFFSET+0x01
#define ERR_SNMP_DB                             SNMP_OFFSET+0x02
#define ERR_SNMP_MEMORY                         SNMP_OFFSET+0x03

/**********************************************************/
/* Error codes for System Configuration                   */
/**********************************************************/
#define ERR_SYSCONF_BOARDPOS_WARNING       SYSCONF_OFFSET+0x00+X_WRN /* Maybe wrong no. of Board Position */
#define ERR_SYSCONF_ALR_REP                SYSCONF_OFFSET+0x01 /* Alarm reporting failed */
#define ERR_SYSCONF_ALR_RET                SYSCONF_OFFSET+0x02 /* Alarm retreating failded */
#define ERR_SYSCONF_RTDB                   SYSCONF_OFFSET+0x03 /* DB error */
#define	ERR_SYSCONF_MALLOC                 SYSCONF_OFFSET+0x04 /* Error memory allocation */
#define	ERR_SYSCONF_SNODE                  SYSCONF_OFFSET+0x05 /* Error finding S_NODE */
#define ERR_SYSCONF_BOARDPOS               SYSCONF_OFFSET+0x06 /* Error finding Board position */
#define ERR_SYSCONF_SNODE_INFO             SYSCONF_OFFSET+0x07+X_INF /* Info change no. of S_NODE */
#define ERR_SYSCONF_GEOSYSUID_INFO         SYSCONF_OFFSET+0x08+X_INF /* Info change no. of geosys_user_id */
#define ERR_SYSCONF_BOARDPOS_INFO          SYSCONF_OFFSET+0x09+X_INF /* Info change no. of board_pos */

/**********************************************************/
/* Error codes for Redundancy Communication Manager - RCM */
/**********************************************************/
#define ERR_RCM_ALARM_REPORT               RCM_OFFSET+0x00 /* Error reporting alarm */
#define ERR_RCM_ALARM_RETREAT              RCM_OFFSET+0x01 /* Error retreating alarm */
#define ERR_RCM_DBE                        RCM_OFFSET+0x02 /* Error reading database */
#define ERR_RCM_MSGGET                     RCM_OFFSET+0x03 /* Error creating message queue */
#define ERR_RCM_MSGRCV                     RCM_OFFSET+0x04 /* Error receiving message */
#define ERR_RCM_MSGSND                     RCM_OFFSET+0x05 /* Error sending message */
#define ERR_RCM_SNMP                       RCM_OFFSET+0x06 /* Error in SNMP communication */
#define ERR_RCM_FORK                       RCM_OFFSET+0x07 /* Error creating new process */
#define ERR_RCM_PTHREAD_CREATE             RCM_OFFSET+0x08 /* Error creating new thread */
#define ERR_RCM_SEMINIT                    RCM_OFFSET+0x09 /* Error initializing semaphore */
#define ERR_RCM_SEMGET                     RCM_OFFSET+0x0a /* Error taking semaphore */
#define ERR_RCM_SEMGIVE                    RCM_OFFSET+0x0b /* Error giving semaphore */

# endif		/* _C_ERRCODE_H */

