/*########################################################################*/
/*#                                                                      #*/
/*#                                                                      #*/
/*#           Copyright (c) 2004 IskraTEL                                #*/
/*#                                                                      #*/
/*#                                                                      #*/
/*# Name        : ipcs_keys.h                                            #*/
/*#                                                                      #*/
/*# Description : Keys for IPCS (InterProcessing Communication)          #*/
/*#               for SDL application.                                   #*/
/*#                                                                      #*/
/*# Date        : Apr 2004                                               #*/
/*#                                                                      #*/
/*# Author      : Valerij Grasic                                         #*/
/*#                                                                      #*/
/*# Remarks     :                                                        #*/
/*#                                                                      #*/
/*# Revisions   :                                                        #*/
/*#                                                                      #*/
/*########################################################################*/

#ifndef _IPCS_KEYS_H
#define _IPCS_KEYS_H

/****************************************************************/
/*          LIBRARIES                                           */
/****************************************************************/
#include <sys/types.h>
#include <sys/ipc.h>
#include <sys/shm.h>
#include <unistd.h>

/****************************************************************/
/*          SYMBOLIC  CONSTANTS AND MACROS                      */
/****************************************************************/
/* Message Queue Permission Mode */
#define MSG_MOD    0700

/* Semaphore Permission Mode */
#define SEM_MOD    0660

/* Shared Memory Permission Mode */
#define SHM_MOD    0660

/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/* SS7 ISUP */
#define SHMKEY_ISUP_T			0x00001000    /* key for ISUP table isup_t_p  */
#define SHMKEY_CIC_T			0x00001001    /* key for ISUP table cic_t_p   */
#define SEMKEY_CIC_T                    0x00001002    /* key for ISUP table semaphore*/

#define SHMKEY_TME			0x00001010    /* key for time measuring shm*/

/*CMU*/
#define SHMKEY_CMU_CS			0x00001011    /* key for console menu shm - CS*/
#define SEMKEY_CMU_CS			0x00001012    /* key for console menu semaphore - CS*/
#define SEMKEY_CMU_SHMPROT_CS		0x00001013    /* key for console menu semaphore for controling access to shm - CS*/
#define SHMKEY_CMU_MG			0x00001014    /* key for console menu shm - MG*/
#define SEMKEY_CMU_MG			0x00001015    /* key for console menu semaphore - MG*/
#define SEMKEY_CMU_SHMPROT_MG		0x00001016    /* key for console menu semaphore for controling access to shm - MG*/
#define SHMKEY_CMU_HAM			0x00001017    /* key for console menu shm - HAM*/
#define SEMKEY_CMU_HAM			0x00001018    /* key for console menu semaphore - HAM*/
#define SEMKEY_CMU_SHMPROT_HAM		0x00001019    /* key for console menu semaphore for controling access to shm - HAM*/
#define SHMKEY_CMU			SHMKEY_CMU_CS /* default key for console menu shm*/
#define SEMKEY_CMU			SEMKEY_CMU_CS /* default key for console menu semaphore*/
#define SEMKEY_CMU_SHMPROT		SEMKEY_CMU_SHMPROT_CS /* default key for console menu semaphore for controling access to shm*/

/* DS */
#define SHMKEY_DS_CS                    0x00001100    /* ds - Tappl checkpointing first key for CS application*/
#define SHMKEY_DS_MG                    0x00001170    /* ds - Tappl checkpointing first key for MG application*/
#define SHMKEY_DS                       SHMKEY_DS_CS  /* ds - Tappl checkpointing first key*/
#define SHMKEY_DS_MAX                   0x000011f0    /* ds - Tappl checkpointing max key*/
#define SEMKEY_DS_CS                    0x000011f1    /* ds - Tappl checkpointing semaphore key for CS application*/
#define SEMKEY_DS_MG                    0x000011f2    /* ds - Tappl checkpointing semaphore key for MG application*/
#define SEMKEY_DS                       SEMKEY_DS_CS  /* ds - Tappl checkpointing semaphore key*/

/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/* HATA */
#define SEMKEY_HATA_CS                  0x00001301    /* hata-cs - hata module semaphore key*/
#define SHMKEY_HATA_CS                  0x00001303    /* hata-cs - hata module shm key*/

#define SEMKEY_HATA_MGCVA               0x00001311    /* hata-mgcva - hata module semaphore key*/
#define SHMKEY_HATA_MGCVA               0x00001313    /* hata-mgcva- hata module shm key*/

#define SEMKEY_HATA_MGPCU               0x00001321    /* hata-mgcva - hata module semaphore key*/
#define SHMKEY_HATA_MGPCU               0x00001323    /* hata-mgcva- hata module shm key*/

#define SEMKEY_HATA_MSMCU               0x00001331    /* hata-msmcu - hata module semaphore key*/
#define SHMKEY_HATA_MSMCU               0x00001333    /* hata-msmcu - hata module shm key*/

#define SEMKEY_HATA_MSMPU               0x00001341    /* hata-msmpu - hata module semaphore key*/
#define SHMKEY_HATA_MSMPU               0x00001343    /* hata-msmpu - hata module shm key*/

#define SEMKEY_HATA			SEMKEY_HATA_CS /* hata - hata module default semaphore key*/
#define SHMKEY_HATA			SHMKEY_HATA_CS /* hata - hata module default shm key*/

/* NTFM */
#define SHMKEY_NTFM			0x00001310    /* ntfm - ntfm module shm key*/


/* LOGT */
#define MSGKEY_LOGT			0x00001304    /* logt - logt module msg key*/

/* KKIPC */
#define MSGKEY_KKIPC			0x00001200    /* kkipc - kkipc module first key*/
#define MSGKEY_KKIPC_MAX 0x000012ff			/* kkipc - kkipc module max key*/

/* OPC */
#define SEMKEY_OPC			0x00001305    /* opc - opc module semaphore key*/
#define SHMKEY_OPC			0x00001306    /* opc - opc module shm key*/

/* SYSUP */
#define SEMKEY_SYSUP			0x00001309  /* sysup - sysup module console semaphore key*/
#define SEMKEY_SYSUP2			0x0000130a  /* sysup - sysup module semaphore key*/
#define SHMKEY_SYSUP			0x0000130b  /* sysup - sysup module shm key*/

/*PKT_SMEM*/
#define SHMKEY_SDL_TIPC_CS 0x00001350
#define SEMKEY_SDL_TIPC_CS 0x00001351
#define MSGQKEY_SDL_TIPC_CS 0x00001352
#define SHMKEY_SDL_TIPC_MGCVA 0x00001353
#define SEMKEY_SDL_TIPC_MGCVA 0x00001354
#define MSGQKEY_SDL_TIPC_MGCVA 0x00001355
#define SHMKEY_SDL_TIPC_MGPCU 0x00001356
#define SEMKEY_SDL_TIPC_MGPCU 0x00001357
#define MSGQKEY_SDL_TIPC_MGPCU 0x00001358
#define SHMKEY_SDL_TIPC SHMKEY_SDL_TIPC_MGCVA
#define SEMKEY_SDL_TIPC SEMKEY_SDL_TIPC_MGCVA
#define MSGQKEY_SDL_TIPC MSGQKEY_SDL_TIPC_MGCVA

/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/************************************************
 * HAM related IPC keys. 32 values between 0x1400
 * and 0x141f reserved.
 * Don't change and don't use these reserved
 * values for other purposes!
 ************************************************/
#define MSGKEY_HAM			0x00001400      /* mwd main message queue key */
#define MSGQKEY_SOCSRV_THR		0x00001401      /* mwd socket server message queue key */
#define MSGQKEY_SOCCLI_THR		0x00001402      /* mwd socket client message queue key */
#define MSGQKEY_DBWD			0x00001403      /* dbwd message queue key */
#define MSGQKEY_MWDMSGS			0x00001404      /* mwdmsgs messga queue key (installNE) */
#define MSGQKEY_ITHB                    0x00001405      /* it heartbeat message queue key */
#define MSGKEY_HT			0x00001410      /* PROXYs keys used for HAM testing (from 1410 to 141f)*/

#define MSGKEY_GHAM			0x00001440      /* gham/ghb main message queue key */
#define MSGQKEY_GHBSOCSRV_THR		0x00001441      /* ghb socket server message queue key */
#define MSGQKEY_GHBSOCCLI_THR		0x00001442      /* ghb socket client message queue key */
#define MSGQKEY_GHAM_THR		0x00001443      /* gham thread FSM message queue key */
#define MSGKEY_GHAMP			0x00001444      /* gham proxy message queue key */

#define MSGKEY_UHAM                     0x00001480      /* uham main message queue key */
#define MSGKEY_UHAMP                    0x00001481      /* uham proxy message queue key */
#define MSGQKEY_UHAMCHKP_THR            0x00001482      /* uham checkpointing thread message queue key */
#define SHMKEY_UHAMP                    0x00001483      /* uham proxy shm key */
#define MSGQKEY_UHAMP                   0x00001484      /* uham proxy message queue key */

/*== DBC keys defines ==*/
#define SHMKEY_DBC_CS_COMMON            0x00001500      /* DBC-CS: shm for common data of DBC */
#define SHMKEY_DBC_CS                   0x00a00000      /* DBC-CS: shm for user data of DBC - reserved from 0x00a00000 to 0xafffff*/
#define SEMKEY_DBC_CS                   0x00001501      /* DBC-CS: DBC semaphore */
#define MSGKEY_SQLI_CS                  0x00001502      /* DBC-CS: message queue for SQLi */

#define SHMKEY_DBC_MGCVA_COMMON         0x00001503      /* DBC-MGCVA: shm for common data of DBC */
#define SHMKEY_DBC_MGCVA                0x00b00000      /* DBC-MGCVA: shm for user data of DBC - reserved from 0x00b00000 to 0xbfffff*/
#define SEMKEY_DBC_MGCVA                0x00001504      /* DBC-MGCVA: DBC semaphore */
#define MSGKEY_SQLI_MGCVA               0x00001505      /* DBC-MGCVA: message queue for SQLi */

#define SHMKEY_DBC_COMMON               SHMKEY_DBC_CS_COMMON   /* DBC-default: shm for common data of DBC */
#define SHMKEY_DBC                      SHMKEY_DBC_CS   /* DBC-default: shm for user data of DBC */
#define SEMKEY_DBC                      SEMKEY_DBC_CS   /* DBC-default: DBC semaphore */
#define MSGKEY_SQLI                     MSGKEY_SQLI_CS  /* DBC-default: message queue for SQLi */

/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/* SS7 MTP */
#define SHMKEY_MTPLINK_T		0x00001600    /* key for MTP linktab */
#define SHMKEY_MTPDEST_T		0x00001601    /* key for MTP desttab */
#define SHMKEY_MTPSET_T			0x00001602    /* key for MTP settab */
#define SHMKEY_MTPOWNSP_T		0x00001603    /* key for MTP ownsptab */
#define SHMKEY_MTPROUT_T		0x00001604    /* key for MTP routtab */
#define SHMKEY_MTPTSRCROUT_T		0x00001605    /* key for MTP tsrcrouttab */
#define SHMKEY_MTPROUTING_T		0x00001606    /* key for MTP routingtab */
#define SHMKEY_MTPCONFIG_T		0x00001607    /* key for MTP configtab */
#define SHMKEY_MTPRELAYVAR		0x00001608    /* key for MTP relay variable */
#define SHMKEY_MTPRELAY_T		0x00001609    /* key for MTP relay table */
#define SHMKEY_MTPBUFFERS_T		0x0000160A    /* key for MTP buffers */
#define SHMKEY_MTPL2LINK_T		0x0000160B    /* key for MTP L2 linktab */
#define SHMKEY_MTPL3TIMERS_T		0x0000160C    /* key for MTPL3 timers */
#define SHMKEY_MTPMIGRATIONVAR		0x0000160D    /* key for SS7 Migration from TDM to SSW table */
#define SHMKEY_MTPMIGRATION_T		0x0000160E    /* key for SS7 Migration from TDM to SSW table */
/* SS7 TCAP */
#define SHMKEY_TCAPDIALOG_T		0x00001801    /* key for TCAP Dialog table */
#define SHMKEY_TCAPSSN_T		0x00001802    /* key for TCAP subsystem number table */
#define SHMKEY_TCAPTRANSAC_T		0x00001803    /* key for TCAP transaction table */
#define SHMKEY_TCAPOAM_T		0x00001808    /* key for TCAP transaction table */
#define SHMKEY_TCAPDIALOGPRTN_T         0x0000180c    /* key for TCAP dialog portion table */
/* SS7 SCCP */
#define SHMKEY_SCCPSCCP_T		0x00001804    /* key for SCCP sccp table */
#define SHMKEY_SCCPSS_T			0x00001805    /* key for SCCP subsystem table */
#define SHMKEY_SCCPDEST_T		0x00001806    /* key for SS7 Destination table */
#define SHMKEY_SCCPOWNSP_T		0x00001807    /* key for SS7 Own Signalling Point table */
#define SHMKEY_PRINTMTP_V		0x00001809    /* key for SS7 console */
#define SHMKEY_XCCCHANNEL_T		0x0000180a    /* key for xcc channel table */
#define SHMKEY_TDMCHANNEL_T		0x0000180b    /* key for TDM channel table */
#define SHMKEY_PRINTTCAP_T		0x0000180d    /* key for TCAP console */
#define SHMKEY_PRINTSCCP_T		0x0000180e    /* key for SCCP console */
#define SHMKEY_SCCPGTT_T		0x0000180f    /* key for SCCP GTT table */
#define SHMKEY_SCCPGTT_ROUTE_T		0x00001810    /* key for SCCP GTT Route table */
#define SHMKEY_SCCPGTT_DEST_T		0x00001811    /* key for SCCP GTT Dest table */

/* SORM */
#define SHMKEY_CM                0x00002000    /* key for SORM common shared memory */
#define SEMKEY_CM                0x00002001    /* key for SORM semaphores memory */
#define SHMKEY_CM_PFXCONV_TYPE1  0x00002002    /* key for SORM shared memory for conversions prefix type 1 */
#define SHMKEY_CM_PFXCONV_TYPE2  0x00002003    /* key for SORM shared memory for conversions prefix type 2 */
#define SHMKEY_CM_PFXCONV_TYPE3  0x00002004    /* key for SORM shared memory for conversions prefix type 3 */
#define SHMKEY_CM_PFXCONV_TYPE4  0x00002004    /* key for SORM shared memory for conversions prefix type 4 */
#define SHMKEY_CM_PFXCONV_TYPE5  0x00002006    /* key for SORM shared memory for conversions prefix type 5 */
#define SHMKEY_CM_PFXCONV_TYPE6  0x00002007    /* key for SORM shared memory for conversions prefix type 6 */


/*ETSI LI*/
#define SHMKEY_LI			0x00002100    /* key for LI shared memory */
#define SEMKEY_LI			0x00002101    /* key for LI semaphores memory */


/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/*== HDLC ==*/
#define SHMKEY_HDLC_HDLCCHINITSTRUCT	0x00003100


/*== DSS1 L2 ==*/
#define SHMKEY_DSS1L2_VIRTMODULESTR	0x00003200
#define SHMKEY_DSS1L2_MODULESTR		0x00003201
#define SHMKEY_DSS1L2_V5LINKSTR		0x00003202
#define SHMKEY_DSS1L2_V5TSSTR		0x00003203
#define SHMKEY_DSS1L2_PORTSTR		0x00003204
#define SEMKEY_DSS1L2_PORTSTR		0x00003214	/* semaphore key */
#define SHMKEY_DSS1L2_ACTIVEPORTS	0x00003205
#define SEMKEY_DSS1L2_ACTIVEPORTSGET	0x00003215	/* semaphore key */
#define SEMKEY_DSS1L2_ACTIVEPORTSPID	0x00003216	/* semaphore key */
#define SHMKEY_DSS1L2_COMMON_DATA	0x00003206

/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/*== DSS1 L3 ==*/
/*== for CS only: tables are defined in u_t_sint_c.c ==*/
#define SHMKEY_DSS1_CODESET_END_INDEX	0x00003311      /* key for codeset_end_index */
#define SHMKEY_DSS1_DIF_IE		0x00003312      /* key for dif_IE */
#define SHMKEY_DSS1_IE_TABLE_PTR	0x00003313      /* key for IE_table_ptr */
#define SHMKEY_DSS1_NUM_OF_DIF_IE	0x00003314      /* key for num_of_dif_IE */
#define SHMKEY_DSS1_TABLE_PTR		0x00003315      /* key for table_ptr */

/*== QSIG L3 ==*/
/*== for CS only: tables are defined in u_t_sintq_c.c ==*/
#define SHMKEY_QSIG_CODESETQ_END_INDEX	0x00003331      /* key for codeset_end_index */
#define SHMKEY_QSIG_DIF_IE		0x00003332      /* key for dif_IE */
#define SHMKEY_QSIG_IE_TABLEQ_PTR	0x00003333      /* key for IE_table_ptr */
#define SHMKEY_QSIG_NUM_OF_DIF_IE	0x00003334      /* key for num_of_dif_IE */
#define SHMKEY_QSIG_TABLE_PTR		0x00003335      /* key for table_ptr */


/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/*
  __| (_) __ _  __ _ _ __   ___  ___| |_(_) ___ ___
 / _` | |/ _` |/ _` | '_ \ / _ \/ __| __| |/ __/ __|
| (_| | | (_| | (_| | | | | (_) \__ \ |_| | (__\__ \
 \__,_|_|\__,_|\__, |_| |_|\___/|___/\__|_|\___|___/
               |___/
*/
/*== DRH - Diagnostic Report Handler ==*/
#define IPCS_KEYS_DIAG_START		0x00003400	/* start of diag. keys area	*/
#define IPCS_KEYS_DMID_SIZE		0x00000100	/* nr of keys for one diag.mod.	*/
#define IPCS_KEYS_DIAG_SIZE		0x00000C00	/* nr of keys for whole diag.	*/
#define SHMKEY_DRH_MOD_CNT		IPCS_KEYS_DIAG_START	/* DRH modules count		*/
#define SHMKEY_DRH_MOD_MAX		4		/* max number of contemporary running DRH modules	*/

#ifdef DIAGNOSTIC_V6			/* "OLD" diagnostics in swconf - DIAGNOSTIC_V6	*/
#define IPCS_KEYS_DIAG_BASE		(IPCS_KEYS_DIAG_START+drhModuleNumber()*(IPCS_KEYS_DMID_SIZE))
#else					/* "NEW" diagnostics in SVN			*/
#define IPCS_KEYS_DIAG_BASE		(IPCS_KEYS_DIAG_START+SHMKEY_DRH_MOD_MAX*(IPCS_KEYS_DMID_SIZE))	/* 0x00003800	*/
#endif					/* diagnostics					*/

#define SHMKEY_DRH_QUE_RPRT		(IPCS_KEYS_DIAG_BASE+0x01)	/* DRH shared memory		*/
#define SEMKEY_DRH_QUE_RPRT		(IPCS_KEYS_DIAG_BASE+0x01)	/* DRH report queue semaphore	*/
#define MSGKEY_DRH_QUE_RPRT		(IPCS_KEYS_DIAG_BASE+0x01)	/* DRH report queue		*/
#define SEMKEY_DRH_QUE_MSG 		(IPCS_KEYS_DIAG_BASE+0x02)	/* DRH message queue semaphore	*/
#define MSGKEY_DRH_QUE_MSG 		(IPCS_KEYS_DIAG_BASE+0x02)	/* DMH message queue		*/
#define SEMKEY_DRH_OSC_ERR 		(IPCS_KEYS_DIAG_BASE+0x03)	/* osc. err. table semaphore	*/
#define SEMKEY_DRH_RPC_CLNT		(IPCS_KEYS_DIAG_BASE+0x04)	/* key for DRH RPC semaphore	*/
#define SEMKEY_DRH_FLT_IND 		(IPCS_KEYS_DIAG_BASE+0x05)	/* key for drhFltIndTB sem.	*/
#define SEMKEY_DRH_SNMP_FLT		(IPCS_KEYS_DIAG_BASE+0x06)	/* key for snmpFaultsTB sem.	*/
#define SHMKEY_DRH_ERR_CNT		(IPCS_KEYS_DIAG_BASE+0x07)	/* ShMem for error counters	*/
#define SHMKEY_DRH_APP_STATE		(IPCS_KEYS_DIAG_BASE+0x08)	/* ShMem for DRH app. state	*/
#define SHMKEY_DRH_HAM_PROXY		(IPCS_KEYS_DIAG_BASE+0x09)	/* ShMem for HAM proxy		*/
#define SEMKEY_DRH_START		(IPCS_KEYS_DIAG_BASE+0x0A)	/* drhMain start sync semaphore	*/
#define	SHMKEY_DRH_AUTO_CONFIG_CHANGE	(IPCS_KEYS_DIAG_BASE+0x0B)	/* auto configuration change detection flag	*/
#define SHMKEY_DIAG_XML_TRIG		(IPCS_KEYS_DIAG_BASE+0x0C)	/* notify message for xml data change	*/
#define MSGKEY_DIAG_DATA_REQ		(IPCS_KEYS_DIAG_BASE+0x10)	/* request diagnostic data	*/
#define MSGKEY_DIAG_DATA_SEND		(IPCS_KEYS_DIAG_BASE+0x11)	/* send/receive diagnostic data	*/
#define MSGKEY_DRH			(IPCS_KEYS_DIAG_BASE+0x12)	/* HAM proxys msg queue	*/
#define MSGKEY_TEST_PROG_CTRL		(IPCS_KEYS_DIAG_BASE+0x14)	/* request test program data	*/
#define MSGKEY_TEST_PROG_DATA		(IPCS_KEYS_DIAG_BASE+0x15)	/* send/receive test prog data	*/
#define SHMKEY_DRH_DEBUG_LEVEL		(IPCS_KEYS_DIAG_BASE+0x16)	/* ShMem DRH debug level	*/
#define SHMKEY_DIAG_SITE_STATE		(IPCS_KEYS_DIAG_BASE+0x17)	/* ShMem DGM site state		*/
#define SHMKEY_UNIT_STATE		(IPCS_KEYS_DIAG_BASE+0x18)	/* ShMem DGM site state		*/

/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/*== ITSHM - Message code description tables ==*/
/***************************************************************************************
*	For every shm segment (table) two keys are defined:				
*	    even (original) and odd (alternate). Two keys are needed for
*	    table reallocations (growth of table)
*****************************************************************************************/
#define SHMKEY_ITSHM_SEGTAB		(IPCS_KEYS_DIAG_BASE+0x20)	/* shm segment table		*/
#define SHMKEY_ITSHM_DESTAB		(IPCS_KEYS_DIAG_BASE+0x30)	/* shm description table	*/
#define SHMKEY_ITSHM_TABLIST		(IPCS_KEYS_DIAG_BASE+0x31)	/* shm list of allocated tables	*/
#define SHMKEY_ITSHM_SEGPOOL		(IPCS_KEYS_DIAG_BASE+0x40)	/* pool of shm segments		*/

#define ITSHM_KEY_POOL_LEN		0x20		/* size of ITSHM keys pool 	*/
/*	keys for 2 (two) pools of message structure tables - each with 0x10 items	*/
#define SHMKEY_ITSHM_MSG		(IPCS_KEYS_DIAG_BASE+0x60)	/* message structure tables	*/
/*	keys for 2 (two) pools of description strings tables - each with 0x10 items	*/
#define SHMKEY_ITSHM_STR		(IPCS_KEYS_DIAG_BASE+0x80)	/* description string tables	*/



#define SHMKEY_DLH_STATE_TBL		(IPCS_KEYS_DIAG_BASE+0xC1)	/* DLH - Daemon state shm key */
#define SHMKEY_DLH_LOG_TABLE		(IPCS_KEYS_DIAG_BASE+0xC2)	/* DLH - Log tables shm key */
#define SHMKEY_DLH_LOG_STATE		(IPCS_KEYS_DIAG_BASE+0xC3)	/* DLH - Log state shm key */
#define SHMKEY_DLH_LOG_TMFLT		(IPCS_KEYS_DIAG_BASE+0xC4)	/* DLH - Log filter shm key */
#define MSGKEY_DLH_MSG_QUEUE		(IPCS_KEYS_DIAG_BASE+0xC5)	/* DLH - Message queue key */
#define SEMKEY_DLH_LOG_REGISTER		(IPCS_KEYS_DIAG_BASE+0xC6)	/* DLH - Register semaphore key */		

#define SHMKEY_ITSHM_END		(IPCS_KEYS_DIAG_BASE+0xFF)	/* end of reserved keys		*/

#define SHMKEY_RPC_TCP                  (IPCS_KEYS_DIAG_BASE+0x101)     /* use TCP protocol instead of UDP                              */
#define SHMKEY_RPC_DYN                  (IPCS_KEYS_DIAG_BASE+0x102)     /* destroy RPC client handle after each completed connection    */
#define SHMKEY_RPC_LING                 (IPCS_KEYS_DIAG_BASE+0x103)     /* use RPC_LINGER function to destroy sockets immedaitely       */
#define SHMKEY_DRH_EXT_ALR              (IPCS_KEYS_DIAG_BASE+0x104)     /* external alarms handler activated				*/

/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/* NOTIFY_MECHANISM */
#define SHMKEY_NMNG_CDCP    		0x00004000    /* Comulative data collecting proccess key */
#define SHMKEY_NMNG_DRH_MAIN		0x00004001    /* DRH - Diagnostic report handler	*/
#define SHMKEY_NMNG_NDCP    		0x00004002    /* NDCP */
#define SHMKEY_NMNG_RECONFIG		0x00004003    /* Reconfig proccess key */
#define SHMKEY_NMNG_LNXADM		0x00004004	/* LINUX Administration	*/
#define SHMKEY_NMNG_EQUIP		0x00004005	/* Equipment Test	*/
#define SHMKEY_NMNG_LIMODULE		0x00004006	/* Legal interception module	*/
#define SHMKEY_NMNG_SYS_PARAM		0x00004007	/* Regular System Parameters	*/
#define SHMKEY_NMNG_PING_TEST		0x00004008	/* Test for Ping	*/
#define SHMKEY_NMNG_BOARD		0x00004009	/* for table - board	*/
#define SHMKEY_NMNG_STRC		0x0000400A	/* STRC - Signalling Tracer	*/
#define SHMKEY_NMNG_STRC_CS		0x0100400A	/* STRC - Signalling Tracer - for CS Application	*/
#define SHMKEY_NMNG_STRC_MG		0x0200400A	/* STRC - Signalling Tracer - for MG Application	*/
#define SHMKEY_NMNG_GLB_SETUP		0x0000400B	/* for table - global_setup	*/
#define	SHMKEY_NMNG_BRDGW		0x0000400C	/* for Border Gateway	*/
#define	SHMKEY_NMNG_DHCP		0x0000400D	/* for Dynamic Host Configuration Protocol	*/
#define	SHMKEY_NMNG_SYNC		0x0000400E	/* Module TDM synchronization	*/

/*== OVERLOAD ==*/
#define SHMKEY_USER_OVERLOAD		0x00005000   /* overload protection for local and transit calls */

/*== ITLOG, PRE-NG ==*/
#define SHMKEY_TIME_SEC			0x00005800	/* ShMem time in seconds	*/

/*== CDCP - Cummulative Data Collecting Process ==*/
#define MSGKEY_CDCP_CHARGE		0x00006000
#define MSGKEY_CDCP_CQUEUE		0x00006001

/*== Node info nodule ==*/
#define	SHMKEY_NODEINFO			0x00007000


/*== Please keep ascending order of KEYS! ==*/
/*== Make definitions in form '#define key_name[TAB][TAB]*0x0000value ==*/
/* Diagnostic test shared memory keys*/
#define DIAGKEY_SYNC			0x00008000		/* Synchronisation control shared memory key*/

/*== Please keep ascending order of KEYS! ==*/
/*== VXML ==*/
#define SHMKEY_VXML_UPLOAD		0x00009000    /* VXML upload process semaphore */

/*== DGM - Diagnostic Monitor keys ==*/
/*== keys from 0x0000A000 are reserved only for diagnostic monitor queues ==*/

#define MSGKEY_DGM_TEST_QUEUE		0x0000A000	/* DGM messages queue for tests	*/
/* LSD */
#define LSDMSGKEY		0x0000B000	/* line status message queue key */

/*== E1 and Sync shm and sem defines ==*/
#define SHMKEY_E1_SYNC			0x0000C000		/* E1-Sync control shared memory key*/
#define SEMKEY_E1_SYNC			0x0000C001		/* E1-Sync control semaphore */
#define SHMKEY_E1_CAS_ALARMS		0x0000C002		/* E1 CAS link alarms */
#define SHMKEY_E1_CAS_MF_ALARMS		0x0000C003		/* E1 CAS link multiframe alarms */
#define SEMKEY_E1_CAS_MF_ALARMS		0x0000C004		/* E1 CAS link multiframe alarms data access semaphore */

/*== V5.2 shm keys ==*/
#define SHMKEY_V52_TABLE		0x0000D000		/* V5.2 global table */
#define  SEMKEY_V52_TABLE		0x0000D011	/* !!!semaphore key for accessing SHMKEY_V52_TABLE */
#define SHMKEY_V52_2MBLINK_TABLE	0x0000D001		/* V5.2 2Mb link table */
#define SHMKEY_V52_2MBLINK_TS_TABLE	0x0000D002		/* V5.2 2Mb timeslot table */
#define SHMKEY_V52_BCC_REFNUM_TABLE	0x0000D003		/* V5.2 BCC Ref. Num. table */
#define SHMKEY_V52_USERPORT_TABLE	0x0000D004		/* V5.2 User Port table */
#define SHMKEY_V52_E1PORT_TABLE		0x0000D005		/* V5.2 E1 Port table */

/*== RTPC shm and sem keys==*/
#define SHMKEY_RTCP_MIB_TABLE		0x0000E001		/* RTCP MIB table */
#define SEMKEY_RTCP_MIB_TABLE		0x0000E002		/* RTCP MIB table semaphore key*/

/*== MOT DSP shm keys  ==*/
#define MSGKEY_DSP_API_QUEUE		0x0000F000		/*  DSP message queue for host-api communication*/
#define MSGKEY_DSP_WDT_QUEUE		0x0000F001		/*  DSP WDT test queue */

/*== E1 and Sync shm defines ==*/
#define SHMKEY_E1_PORT_DATA		0x00010000		/* E1 port status shared data*/
#define SHMKEY_SYNC_DATA		0x00011000		/* sync status shared data*/
#define MSGKEY_SYNCE_ISS		0x00011001		/* synce test to iss communication queue */
#define MSGKEY_ISS_SYNCE		0x00011002		/* iss to synce test communication queue */ 

/*== CSTA shm and sem defines ==*/
#define SHMKEY_CSTA_cID                 0x00012000              /* CSTA variable for generating unique call ID*/
#define SEMKEY_CSTA_cID                 0x00012001              /* semaphore for CSTA variable for generating unique call ID*/

/*== System HAM Proxies ==*/
/*== DRBDP module ==*/
#define	KEY_DRBDP			0x00013000

/*== OVL and OVL proxy module ==*/
#define	KEY_OVLP			0x00013001

#define	KEY_DGMP			0x00013002
#define KEY_DRHP			0x00013003

/*== NET UTILS DATA module ==*/
#define	SHMKEY_NET_UTILS		0x00014000

/*== SYS CONF DATA module ==*/
#define	SHMKEY_SYS_CONF		        0x00014100

/*== next user should start from 0x00015000 ==*/

#define MSGKEY_QID_ZERO                     0x00015000		/* first created message queue in the system (qid = 0)*/
                                                      		/* should not be used for messaging */

/*== hrast message queue keys ==*/
#define MSGKEY_HRAST_MSG                    0x00016000		/* ordinary messages key */ 
#define MSGKEY_HRAST_CB				        0x00016001		/* callback messages key */
#define MSGKEY_HRAST_RX_CB			        0x00016002	/* receive callback messages key */

/*== __RSTP__ rstpd message queue keys ==*/
#define MSGKEY_RSTP_MSG				        0x00017000	/* internal messages key for rstpd */

/*== ext. module report msg defines ==*/
#define MSGKEY_EXT_MOD_REP		0x00020000		/* external module report shared data*/

/*== mlinec msg defines ==*/
#define MSGKEY_MLNC_INTSNDMSQ           0x00020001              /*msg key for sending messages*/
#define MSGKEY_MLNC_INTRCVMSQ           0x00020002              /*msg key for receiving messages*/
#define MSGKEY_MLNC_CALLBACK            0x00020003              /* msg key for callback hrast->mlinec */

/*== lidia msg and shm defines ==*/
#define MSGKEY_LID_NOTIFY		0x00021000		/* message queue for receiving diag. notify messages */
#define MSGKEY_ETH_NOTIFY		0x00021001		/* message queue for receiving eth state change messages */

/*== upr proxy msg defines ==*/
#define MSGKEY_UPRPD                    0x00022000              /*msg key for upr proxy messages*/
#define MSGKEY_UPRPD_PPP_ROUTE_SWITCH   0x00022001              /*msg key for upr proxy ppp route switching*/

/*== DSP VoIP IPC objects ==*/
#define SEMKEY_VOIP_DTG_START               0x00023000          /* traffic generator initializing semaphore */
#define SHMKEY_VOIP_DTG_INIT_INFO           0x00023001          /* 1-byte shared memory holding information whether DTG is initialized or not */
#define SHMKEY_VOIP_DTG_SCENARIO            0x00023002          /* shared memory holding scenario structure */
#define MSGKEY_VOIP_DTG_CONSOLE_QUEUE       0x00023003          /* message queue between console process and tDspTrafficGen process */
#define MSGKEY_DSP_STATS_CONSOLE_MENU_MSGQ	0x00023004          /* message queue between console process and DIM process */

#define SEMKEY_RTP_COMMAND_COMPLETE_SEM     0x00023005
#define MSGKEY_LOG_VIEWER		    0x00023006		/*  log viewer msg queue */
#define SHMKEY_LOG_VIEWER		    0x00023007		/*  log viewer shared memory */
#define MSGKEY_LOG_VIEWER_CALLBACK_CONNECTED                0x00023008		/*  log viewer msg queue for callback connected */
#define MSGKEY_LOG_VIEWER_CALLBACK_DISCONNECTED             0x00023009		/*  log viewer msg queue */
#define MSGKEY_LOG_VIEWER_CALLBACK_DSP_STATISTICS           0x00023010     /*  log viewer msg queue */
#define MSGKEY_LOG_VIEWER_CALLBACK_DSP_ONE_CHAN_DATA_START  0x00023011     /*  log viewer msg queue */
#define MSGKEY_LOG_VIEWER_CALLBACK_DSP_ONE_CHAN_DATA_STOP   0x00023012     /*  log viewer msg queue */
#define MSGKEY_LOG_VIEWER_CALLBACK_DSP_ALL_CHAN_DATA_START  0x00023013     /*  log viewer msg queue */
#define MSGKEY_LOG_VIEWER_CALLBACK_DSP_ALL_CHAN_DATA_STOP   0x00023014     /*  log viewer msg queue */

#define SEMKEY_RTP_REENTRANCY               0x00023015          /* semaphore for reentracy protection for channel data access */
#define SEMKEY_RTP_DSP_RELOAD               0x00023016          /* semaphore for reloading single DSP */
#define MSGKEY_DSP_CMD                      0x00023017          /* queue for dsp command messages  */
#define MSGKEY_PKTAPI_STATS_CONSOLE_MSGQ    0x00023018          /* queue for pktapi statistics  */
#define MSGKEY_AGG_CMD                      0x00023019          /* queue for MFA aggregator menu  */

#define SHMKEY_VXML_PLAY                    0x00023020          /* VXML playout - shared memory between VXML interpreter (A. Orjutin, I. Jaklic) and VXML driver (dim process) */
#define SHMKEY_VXML_RECORD                  0x00023021          /* VXML recording - shared memory between VXML interpreter (A. Orjutin, I. Jaklic) and VXML driver (dim process) */

#define SEMKEY_LOG_VIEWER_MUTEX_LGPRINT_MACROS   0x00023022     /*  prevent multiple processes/threads to use LGPRINT simultaneously  */
#define SHMKEY_VOIP_DTG_VXML_REPLY          0x00023023          /* vxml signals without tcid */


#define SEMKEY_RTP_SYNCHRO_SEMAPHORES       0x00024000          /* this range should be reserved for synchronization semaphores */
/*== DSP VoIP IPC objects END ==*/

/*== LIModule ==*/
#define SHMKEY_LIM_DBTRIG               0x00025000              /*msg key for LIM DB Trigger messages*/
#define SEMKEY_LIM_DBTRIG               0x00025001              /*sem key for LIM DB Trigger messages*/
/*== LIModule END ==*/

/*== Board Pos ==*/
#define SHMKEY_BOARD_POS               0x00026000              /*msg key for board pos for PCU*/
/*== Board Pos END ==*/

/* HAPASSRV - HA proxy for AS services*/
#define SEMKEY_HAPASSRV			0x00027000    /* hapassrv - hapassrv module semaphore key*/
#define MSGKEY_HAPASSRV			0x00027001    /* hapassrv - hapassrv module msg key*/
/* HAPASSRV - HA proxy for AS services - END */
/* HAPWEBSRV - HA proxy for WEB services*/
#define SEMKEY_HAPWEBSRV		0x00027002    /* hapwebsrv - hapwebsrv module semaphore key*/
#define MSGKEY_HAPWEBSRV		0x00027003    /* hapwebsrv - hapwebsrv module msg key*/
/* HAPWEBSRV - HA proxy for WEB services - END */
/* HAPLDAP - HA proxy for LDAPD */
#define SEMKEY_HAPLDAP			0x00027004    /* hapldap - hapldap module semaphore key*/
#define MSGKEY_HAPLDAP			0x00027005    /* hapldap - hapldap module msg key*/
/* HAPLDAP - HA proxy for LDAPD - END */
/* HAPMNSRV - HA proxy for MN services*/
#define SEMKEY_HAPMNSRV			0x00027006    /* hapmnsrv - hapmnsrv module semaphore key*/
#define MSGKEY_HAPMNSRV			0x00027007    /* hapmnsrv - hapmnsrv module msg key*/
/* HAPMNSRV - HA proxy for MN services - END */

/*== Zarlink device shared resources ==*/
#define SEMKEY_ZL_SYNC			0x00028001		/* Zarlink device access control semaphore */

/*== Iskratel MDS shared memory resource ==*/
#define SHMKEY_IT_MDS_SENDER_MIN			0x00029000
/* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	IPC key range from 0x00029000 to 0x000290FF
	is reserved for IT MDS functionality */
#define SHMKEY_IT_MDS_SENDER_MAX			0x000290FF

/* NCFM - Network configuration module */
#define SEMKEY_NCFM             0x00030000 /* ncfm module semaphore key */
/* NCFM - Network configuration module - END*/

/* sysApi - System Application user interface */
#define SEMKEY_SYS_API          0x00030100 /* sysApi module semaphore key */
/* sysApi - System Application user interface - END*/

/* ECFM module */
#define MSGKEY_ECFM_CLI         0x00031000
#define MSGKEY_ECFM_SNMP        0x00031001
#define MSGKEY_ECFM_BLL         0x00031002
#define MSGKEY_ECFM_CNFGR       0x00031003
/* ECFM module - END */

/* HAP module */
#define MSGKEY_HAPLIB_FIRST      0x00032000
#define MSGKEY_HAPLIB_LAST       0x00032fff
#define SEMKEY_HAPLIB_FIRST      0x00033000
#define SEMKEY_HAPLIB_LAST       0x000330ff
/* HAP module - END */

/*== HW initialization ==*/
#define MSGKEY_HW_INIT           0x00034001
#define MSGKEY_HW_INIT_PROXY     0x00034002
#define MSGKEY_HW_INIT_MENU      0x00034003
#define MSGKEY_HW_INIT_SDL       0x00034004
#define SEMKEY_IHWP              0x00034006
#define SEMKEY_HW_INIT           0x00034007
#define SHMKEY_HW_INIT           0x00034008
#define SHMKEY_HW_INIT_TCTX_NODE 0x00034009
/*== HW initialization end ==*/

/*== Redundancy Communication Manager - RCM ==*/
#define MSGKEY_RCM               0x00035001
#define MSGKEY_RCM_MENU          0x00035002
#define SEMKEY_RCM_SYNC          0x00035003
/*== Redundancy Communication Manager end ==*/

/*== IMS TPS licence ==*/
#define SHMKEY_SIP_TPS_cID       0x00036001
#define SEMKEY_SIP_TPS_cID       0x00036002
/*== IMS TPS licence end ==*/

/*== SW initialization ==*/
#define MSGKEY_SW_INIT           0x00037001
#define MSGKEY_SW_INIT_PROXY     0x00037002
#define MSGKEY_SW_INIT_MENU      0x00037003
#define MSGKEY_SW_INIT_SDL       0x00037004
#define SEMKEY_ISWP              0x00037006
#define SEMKEY_SW_INIT           0x00037007
#define SHMKEY_SW_INIT           0x00037008
#define SHMKEY_SW_INIT_TCTX_NODE 0x00037009
/*== SW initialization end ==*/

/*== TESTDBP module ==*/
#define SEMKEY_TESTDB            0x00038001
/*== TESTDBP module end ==*/

/*== SHMCP initialization ==*/
#define MSGKEY_apl_itShMC           0x00039001
#define SHMKEY_apl_itShMC           0x00039002
#define SEMKEY_SHMCP                0x00039003
#define SHMKEY_SHMC_LIB             0x00039004
#define MSGKEY_LIB2SHMC             0x00039005
#define MSGKEY_SHMC2LIB             0x00039006
/*== SHMCP initialization end ==*/

/*== IPMI event queue ==*/
#define IPC_EVENTQUEUE_KEY          0x0003A001
/*== IPMI event queue end ==*/

/*== UPRPD - UPRD floating IP addresses ==*/
#define SHMKEY_F_VOIP               0x0003B000
#define SHMKEY_F_LI                 0x0003C000
#define SHMKEY_F_BGW                0x0003D000
/*== UPRPD - UPRD floating IP addresses ==*/

/*== ITACON event queue ==*/
#define MSGKEY_ITACON_APPL          0x0003E001
#define MSGKEY_CB_APPL              0x0003E801
/*== ITACON event queue end ==*/

/*== SPI ACCESS semaphore     ==*/
#define SEMKEY_SPI_ACCESS           0x0003E101
/*== SPI ACCESS semaphore end ==*/

#endif /* _IPCS_KEYS_H */

